Class: Recurly::Client
- Inherits:
-
Object
- Object
- Recurly::Client
- Includes:
- NetHttpAdapter
- Defined in:
- lib/recurly/client.rb,
lib/recurly/client/adapter.rb,
lib/recurly/client/operations.rb
Defined Under Namespace
Modules: NetHttpAdapter, NetHttpPersistentAdapter
Constant Summary collapse
- BASE_URL =
"https://v3.recurly.com/"- BINARY_TYPES =
[ "application/pdf", ]
Instance Method Summary collapse
- #api_version ⇒ Object
-
#cancel_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Cancel a subscription.
-
#collect_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Collect a pending or past due, automatic invoice.
-
#create_account(body:, **options) ⇒ Resources::Account
Create an account.
-
#create_coupon(body:, **options) ⇒ Resources::Coupon
Create a new coupon.
-
#create_coupon_redemption(account_id:, body:, **options) ⇒ Resources::CouponRedemption
Generate an active coupon redemption on an account.
-
#create_invoice(account_id:, body:, **options) ⇒ Resources::InvoiceCollection
Create an invoice for pending line items.
-
#create_item(body:, **options) ⇒ Resources::Item
Create a new item.
-
#create_line_item(account_id:, body:, **options) ⇒ Resources::LineItem
Create a new line item for the account.
-
#create_plan(body:, **options) ⇒ Resources::Plan
Create a plan.
-
#create_plan_add_on(plan_id:, body:, **options) ⇒ Resources::AddOn
Create an add-on.
-
#create_purchase(body:, **options) ⇒ Resources::InvoiceCollection
Create a new purchase.
-
#create_shipping_address(account_id:, body:, **options) ⇒ Resources::ShippingAddress
Create a new shipping address for the account.
-
#create_subscription(body:, **options) ⇒ Resources::Subscription
Create a new subscription.
-
#create_subscription_change(subscription_id:, body:, **options) ⇒ Resources::SubscriptionChange
Create a new subscription change.
-
#deactivate_account(account_id:, **options) ⇒ Resources::Account
Deactivate an account.
-
#deactivate_item(item_id:, **options) ⇒ Resources::Item
Deactivate an item.
-
#deactivate_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Deactivate a unique coupon code.
-
#fail_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Mark an open invoice as failed.
-
#get_account(account_id:, **options) ⇒ Resources::Account
Fetch an account.
-
#get_account_acquisition(account_id:, **options) ⇒ Resources::AccountAcquisition
Fetch an account’s acquisition data.
-
#get_account_balance(account_id:, **options) ⇒ Resources::AccountBalance
Fetch an account’s balance and past due status.
-
#get_account_note(account_id:, account_note_id:, **options) ⇒ Resources::AccountNote
Fetch an account note.
-
#get_active_coupon_redemption(account_id:, **options) ⇒ Resources::CouponRedemption
Show the coupon redemption that is active on an account.
-
#get_add_on(add_on_id:, **options) ⇒ Resources::AddOn
Fetch an add-on.
-
#get_billing_info(account_id:, **options) ⇒ Resources::BillingInfo
Fetch an account’s billing information.
-
#get_coupon(coupon_id:, **options) ⇒ Resources::Coupon
Fetch a coupon.
-
#get_credit_payment(credit_payment_id:, **options) ⇒ Resources::CreditPayment
Fetch a credit payment.
-
#get_custom_field_definition(custom_field_definition_id:, **options) ⇒ Resources::CustomFieldDefinition
Fetch an custom field definition.
-
#get_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Fetch an invoice.
-
#get_invoice_pdf(invoice_id:, **options) ⇒ Resources::BinaryFile
Fetch an invoice as a PDF.
-
#get_item(item_id:, **options) ⇒ Resources::Item
Fetch an item.
-
#get_line_item(line_item_id:, **options) ⇒ Resources::LineItem
Fetch a line item.
-
#get_plan(plan_id:, **options) ⇒ Resources::Plan
Fetch a plan.
-
#get_plan_add_on(plan_id:, add_on_id:, **options) ⇒ Resources::AddOn
Fetch a plan’s add-on.
-
#get_shipping_address(account_id:, shipping_address_id:, **options) ⇒ Resources::ShippingAddress
Fetch an account’s shipping address.
-
#get_shipping_method(id:, **options) ⇒ Resources::ShippingMethod
Fetch a shipping method.
-
#get_site(site_id:) ⇒ Resources::Site
Fetch a site.
-
#get_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Fetch a subscription.
-
#get_subscription_change(subscription_id:, **options) ⇒ Resources::SubscriptionChange
Fetch a subscription’s pending change.
-
#get_transaction(transaction_id:, **options) ⇒ Resources::Transaction
Fetch a transaction.
-
#get_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Fetch a unique coupon code.
-
#initialize(api_key:, site_id: nil, subdomain: nil, **options) {|_self| ... } ⇒ Client
constructor
Initialize a client.
-
#list_account_acquisition(**options) ⇒ Pager<Resources::AccountAcquisition>
List a site’s account acquisition data.
-
#list_account_coupon_redemptions(account_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions for an account.
-
#list_account_credit_payments(account_id:, **options) ⇒ Pager<Resources::CreditPayment>
List an account’s credit payments.
-
#list_account_invoices(account_id:, **options) ⇒ Pager<Resources::Invoice>
List an account’s invoices.
-
#list_account_line_items(account_id:, **options) ⇒ Pager<Resources::LineItem>
List an account’s line items.
-
#list_account_notes(account_id:, **options) ⇒ Pager<Resources::AccountNote>
Fetch a list of an account’s notes.
-
#list_account_subscriptions(account_id:, **options) ⇒ Pager<Resources::Subscription>
List an account’s subscriptions.
-
#list_account_transactions(account_id:, **options) ⇒ Pager<Resources::Transaction>
List an account’s transactions.
-
#list_accounts(**options) ⇒ Pager<Resources::Account>
List a site’s accounts.
-
#list_add_ons(**options) ⇒ Pager<Resources::AddOn>
List a site’s add-ons.
-
#list_child_accounts(account_id:, **options) ⇒ Pager<Resources::Account>
List an account’s child accounts.
-
#list_coupons(**options) ⇒ Pager<Resources::Coupon>
List a site’s coupons.
-
#list_credit_payments(**options) ⇒ Pager<Resources::CreditPayment>
List a site’s credit payments.
-
#list_custom_field_definitions(**options) ⇒ Pager<Resources::CustomFieldDefinition>
List a site’s custom field definitions.
-
#list_invoice_coupon_redemptions(invoice_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions applied to an invoice.
-
#list_invoice_line_items(invoice_id:, **options) ⇒ Pager<Resources::LineItem>
List an invoice’s line items.
-
#list_invoices(**options) ⇒ Pager<Resources::Invoice>
List a site’s invoices.
-
#list_items(**options) ⇒ Pager<Resources::Item>
List a site’s items.
-
#list_line_items(**options) ⇒ Pager<Resources::LineItem>
List a site’s line items.
-
#list_plan_add_ons(plan_id:, **options) ⇒ Pager<Resources::AddOn>
List a plan’s add-ons.
-
#list_plans(**options) ⇒ Pager<Resources::Plan>
List a site’s plans.
-
#list_related_invoices(invoice_id:, **options) ⇒ Pager<Resources::Invoice>
List an invoice’s related credit or charge invoices.
-
#list_shipping_addresses(account_id:, **options) ⇒ Pager<Resources::ShippingAddress>
Fetch a list of an account’s shipping addresses.
-
#list_shipping_methods(**options) ⇒ Pager<Resources::ShippingMethod>
List a site’s shipping methods.
-
#list_sites(**options) ⇒ Pager<Resources::Site>
List sites.
-
#list_subscription_coupon_redemptions(subscription_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions for a subscription.
-
#list_subscription_invoices(subscription_id:, **options) ⇒ Pager<Resources::Invoice>
List a subscription’s invoices.
-
#list_subscription_line_items(subscription_id:, **options) ⇒ Pager<Resources::LineItem>
List a subscription’s line items.
-
#list_subscriptions(**options) ⇒ Pager<Resources::Subscription>
List a site’s subscriptions.
-
#list_transactions(**options) ⇒ Pager<Resources::Transaction>
List a site’s transactions.
-
#list_unique_coupon_codes(coupon_id:, **options) ⇒ Pager<Resources::UniqueCouponCode>
List unique coupon codes associated with a bulk coupon.
-
#mark_invoice_successful(invoice_id:, **options) ⇒ Resources::Invoice
Mark an open invoice as successful.
-
#modify_subscription(subscription_id:, body:, **options) ⇒ Resources::Subscription
Modify a subscription.
- #next_page(pager) ⇒ Object
-
#pause_subscription(subscription_id:, body:, **options) ⇒ Resources::Subscription
Pause subscription.
-
#preview_invoice(account_id:, body:, **options) ⇒ Resources::InvoiceCollection
Preview new invoice for pending line items.
-
#preview_purchase(body:, **options) ⇒ Resources::InvoiceCollection
Preview a new purchase.
-
#put_invoice(invoice_id:, body:, **options) ⇒ Resources::Invoice
Update an invoice.
-
#reactivate_account(account_id:, **options) ⇒ Resources::Account
Reactivate an inactive account.
-
#reactivate_item(item_id:, **options) ⇒ Resources::Item
Reactivate an inactive item.
-
#reactivate_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Reactivate a canceled subscription.
-
#reactivate_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Restore a unique coupon code.
-
#refund_invoice(invoice_id:, body:, **options) ⇒ Resources::Invoice
Refund an invoice.
-
#remove_account_acquisition(account_id:, **options) ⇒ Empty
Remove an account’s acquisition data.
-
#remove_billing_info(account_id:, **options) ⇒ Empty
Remove an account’s billing information.
-
#remove_coupon_redemption(account_id:, **options) ⇒ Resources::CouponRedemption
Delete the active coupon redemption from an account.
-
#remove_line_item(line_item_id:, **options) ⇒ Empty
Delete an uninvoiced line item.
-
#remove_plan(plan_id:, **options) ⇒ Resources::Plan
Remove a plan.
-
#remove_plan_add_on(plan_id:, add_on_id:, **options) ⇒ Resources::AddOn
Remove an add-on.
-
#remove_shipping_address(account_id:, shipping_address_id:, **options) ⇒ Empty
Remove an account’s shipping address.
-
#remove_subscription_change(subscription_id:, **options) ⇒ Empty
Delete the pending subscription change.
-
#reopen_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Reopen a closed, manual invoice.
-
#resume_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Resume subscription.
-
#terminate_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Terminate a subscription.
-
#update_account(account_id:, body:, **options) ⇒ Resources::Account
Modify an account.
-
#update_account_acquisition(account_id:, body:, **options) ⇒ Resources::AccountAcquisition
Update an account’s acquisition data.
-
#update_billing_info(account_id:, body:, **options) ⇒ Resources::BillingInfo
Set an account’s billing information.
-
#update_coupon(coupon_id:, body:, **options) ⇒ Resources::Coupon
Update an active coupon.
-
#update_item(item_id:, body:, **options) ⇒ Resources::Item
Update an active item.
-
#update_plan(plan_id:, body:, **options) ⇒ Resources::Plan
Update a plan.
-
#update_plan_add_on(plan_id:, add_on_id:, body:, **options) ⇒ Resources::AddOn
Update an add-on.
-
#update_shipping_address(account_id:, shipping_address_id:, body:, **options) ⇒ Resources::ShippingAddress
Update an account’s shipping address.
-
#void_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Void a credit invoice.
Constructor Details
#initialize(api_key:, site_id: nil, subdomain: nil, **options) {|_self| ... } ⇒ Client
Initialize a client. It requires an API key.
43 44 45 46 47 48 49 50 |
# File 'lib/recurly/client.rb', line 43 def initialize(api_key:, site_id: nil, subdomain: nil, **) set_site_id(site_id, subdomain) () set_faraday_connection(api_key) # execute block with this client if given yield(self) if block_given? end |
Instance Method Details
#api_version ⇒ Object
7 8 9 |
# File 'lib/recurly/client/operations.rb', line 7 def api_version "v2019-10-10" end |
#cancel_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Cancel a subscription
2404 2405 2406 2407 |
# File 'lib/recurly/client/operations.rb', line 2404 def cancel_subscription(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/cancel", subscription_id: subscription_id) put(path, [:body], Requests::SubscriptionCancel, **) end |
#collect_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Collect a pending or past due, automatic invoice
1591 1592 1593 1594 |
# File 'lib/recurly/client/operations.rb', line 1591 def collect_invoice(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/collect", invoice_id: invoice_id) put(path, [:body], Requests::InvoiceCollect, **) end |
#create_account(body:, **options) ⇒ Resources::Account
Create an account
145 146 147 148 |
# File 'lib/recurly/client/operations.rb', line 145 def create_account(body:, **) path = interpolate_path("/accounts") post(path, body, Requests::AccountCreate, **) end |
#create_coupon(body:, **options) ⇒ Resources::Coupon
Create a new coupon
1198 1199 1200 1201 |
# File 'lib/recurly/client/operations.rb', line 1198 def create_coupon(body:, **) path = interpolate_path("/coupons") post(path, body, Requests::CouponCreate, **) end |
#create_coupon_redemption(account_id:, body:, **options) ⇒ Resources::CouponRedemption
Generate an active coupon redemption on an account
489 490 491 492 |
# File 'lib/recurly/client/operations.rb', line 489 def create_coupon_redemption(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/coupon_redemptions/active", account_id: account_id) post(path, body, Requests::CouponRedemptionCreate, **) end |
#create_invoice(account_id:, body:, **options) ⇒ Resources::InvoiceCollection
Create an invoice for pending line items
625 626 627 628 |
# File 'lib/recurly/client/operations.rb', line 625 def create_invoice(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/invoices", account_id: account_id) post(path, body, Requests::InvoiceCreate, **) end |
#create_item(body:, **options) ⇒ Resources::Item
Create a new item
1412 1413 1414 1415 |
# File 'lib/recurly/client/operations.rb', line 1412 def create_item(body:, **) path = interpolate_path("/items") post(path, body, Requests::ItemCreate, **) end |
#create_line_item(account_id:, body:, **options) ⇒ Resources::LineItem
Create a new line item for the account
734 735 736 737 |
# File 'lib/recurly/client/operations.rb', line 734 def create_line_item(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/line_items", account_id: account_id) post(path, body, Requests::LineItemCreate, **) end |
#create_plan(body:, **options) ⇒ Resources::Plan
Create a plan
1958 1959 1960 1961 |
# File 'lib/recurly/client/operations.rb', line 1958 def create_plan(body:, **) path = interpolate_path("/plans") post(path, body, Requests::PlanCreate, **) end |
#create_plan_add_on(plan_id:, body:, **options) ⇒ Resources::AddOn
Create an add-on
2064 2065 2066 2067 |
# File 'lib/recurly/client/operations.rb', line 2064 def create_plan_add_on(plan_id:, body:, **) path = interpolate_path("/plans/{plan_id}/add_ons", plan_id: plan_id) post(path, body, Requests::AddOnCreate, **) end |
#create_purchase(body:, **options) ⇒ Resources::InvoiceCollection
Create a new purchase
2841 2842 2843 2844 |
# File 'lib/recurly/client/operations.rb', line 2841 def create_purchase(body:, **) path = interpolate_path("/purchases") post(path, body, Requests::PurchaseCreate, **) end |
#create_shipping_address(account_id:, body:, **options) ⇒ Resources::ShippingAddress
Create a new shipping address for the account
848 849 850 851 |
# File 'lib/recurly/client/operations.rb', line 848 def create_shipping_address(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/shipping_addresses", account_id: account_id) post(path, body, Requests::ShippingAddressCreate, **) end |
#create_subscription(body:, **options) ⇒ Resources::Subscription
Create a new subscription
2291 2292 2293 2294 |
# File 'lib/recurly/client/operations.rb', line 2291 def create_subscription(body:, **) path = interpolate_path("/subscriptions") post(path, body, Requests::SubscriptionCreate, **) end |
#create_subscription_change(subscription_id:, body:, **options) ⇒ Resources::SubscriptionChange
Create a new subscription change
2535 2536 2537 2538 |
# File 'lib/recurly/client/operations.rb', line 2535 def create_subscription_change(subscription_id:, body:, **) path = interpolate_path("/subscriptions/{subscription_id}/change", subscription_id: subscription_id) post(path, body, Requests::SubscriptionChangeCreate, **) end |
#deactivate_account(account_id:, **options) ⇒ Resources::Account
Deactivate an account
219 220 221 222 |
# File 'lib/recurly/client/operations.rb', line 219 def deactivate_account(account_id:, **) path = interpolate_path("/accounts/{account_id}", account_id: account_id) delete(path, **) end |
#deactivate_item(item_id:, **options) ⇒ Resources::Item
Deactivate an item
1449 1450 1451 1452 |
# File 'lib/recurly/client/operations.rb', line 1449 def deactivate_item(item_id:, **) path = interpolate_path("/items/{item_id}", item_id: item_id) delete(path, **) end |
#deactivate_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Deactivate a unique coupon code
2790 2791 2792 2793 |
# File 'lib/recurly/client/operations.rb', line 2790 def deactivate_unique_coupon_code(unique_coupon_code_id:, **) path = interpolate_path("/unique_coupon_codes/{unique_coupon_code_id}", unique_coupon_code_id: unique_coupon_code_id) delete(path, **) end |
#fail_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Mark an open invoice as failed
1613 1614 1615 1616 |
# File 'lib/recurly/client/operations.rb', line 1613 def fail_invoice(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/mark_failed", invoice_id: invoice_id) put(path, **) end |
#get_account(account_id:, **options) ⇒ Resources::Account
Fetch an account
167 168 169 170 |
# File 'lib/recurly/client/operations.rb', line 167 def get_account(account_id:, **) path = interpolate_path("/accounts/{account_id}", account_id: account_id) get(path, **) end |
#get_account_acquisition(account_id:, **options) ⇒ Resources::AccountAcquisition
Fetch an account’s acquisition data
241 242 243 244 |
# File 'lib/recurly/client/operations.rb', line 241 def get_account_acquisition(account_id:, **) path = interpolate_path("/accounts/{account_id}/acquisition", account_id: account_id) get(path, **) end |
#get_account_balance(account_id:, **options) ⇒ Resources::AccountBalance
Fetch an account’s balance and past due status
320 321 322 323 |
# File 'lib/recurly/client/operations.rb', line 320 def get_account_balance(account_id:, **) path = interpolate_path("/accounts/{account_id}/balance", account_id: account_id) get(path, **) end |
#get_account_note(account_id:, account_note_id:, **options) ⇒ Resources::AccountNote
Fetch an account note
790 791 792 793 |
# File 'lib/recurly/client/operations.rb', line 790 def get_account_note(account_id:, account_note_id:, **) path = interpolate_path("/accounts/{account_id}/notes/{account_note_id}", account_id: account_id, account_note_id: account_note_id) get(path, **) end |
#get_active_coupon_redemption(account_id:, **options) ⇒ Resources::CouponRedemption
Show the coupon redemption that is active on an account
459 460 461 462 |
# File 'lib/recurly/client/operations.rb', line 459 def get_active_coupon_redemption(account_id:, **) path = interpolate_path("/accounts/{account_id}/coupon_redemptions/active", account_id: account_id) get(path, **) end |
#get_add_on(add_on_id:, **options) ⇒ Resources::AddOn
Fetch an add-on
2164 2165 2166 2167 |
# File 'lib/recurly/client/operations.rb', line 2164 def get_add_on(add_on_id:, **) path = interpolate_path("/add_ons/{add_on_id}", add_on_id: add_on_id) get(path, **) end |
#get_billing_info(account_id:, **options) ⇒ Resources::BillingInfo
Fetch an account’s billing information
342 343 344 345 |
# File 'lib/recurly/client/operations.rb', line 342 def get_billing_info(account_id:, **) path = interpolate_path("/accounts/{account_id}/billing_info", account_id: account_id) get(path, **) end |
#get_coupon(coupon_id:, **options) ⇒ Resources::Coupon
Fetch a coupon
1220 1221 1222 1223 |
# File 'lib/recurly/client/operations.rb', line 1220 def get_coupon(coupon_id:, **) path = interpolate_path("/coupons/{coupon_id}", coupon_id: coupon_id) get(path, **) end |
#get_credit_payment(credit_payment_id:, **options) ⇒ Resources::CreditPayment
Fetch a credit payment
1310 1311 1312 1313 |
# File 'lib/recurly/client/operations.rb', line 1310 def get_credit_payment(credit_payment_id:, **) path = interpolate_path("/credit_payments/{credit_payment_id}", credit_payment_id: credit_payment_id) get(path, **) end |
#get_custom_field_definition(custom_field_definition_id:, **options) ⇒ Resources::CustomFieldDefinition
Fetch an custom field definition
1364 1365 1366 1367 |
# File 'lib/recurly/client/operations.rb', line 1364 def get_custom_field_definition(custom_field_definition_id:, **) path = interpolate_path("/custom_field_definitions/{custom_field_definition_id}", custom_field_definition_id: custom_field_definition_id) get(path, **) end |
#get_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Fetch an invoice
1530 1531 1532 1533 |
# File 'lib/recurly/client/operations.rb', line 1530 def get_invoice(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}", invoice_id: invoice_id) get(path, **) end |
#get_invoice_pdf(invoice_id:, **options) ⇒ Resources::BinaryFile
Fetch an invoice as a PDF
1568 1569 1570 1571 |
# File 'lib/recurly/client/operations.rb', line 1568 def get_invoice_pdf(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}.pdf", invoice_id: invoice_id) get(path, **) end |
#get_item(item_id:, **options) ⇒ Resources::Item
Fetch an item
1424 1425 1426 1427 |
# File 'lib/recurly/client/operations.rb', line 1424 def get_item(item_id:, **) path = interpolate_path("/items/{item_id}", item_id: item_id) get(path, **) end |
#get_line_item(line_item_id:, **options) ⇒ Resources::LineItem
Fetch a line item
1853 1854 1855 1856 |
# File 'lib/recurly/client/operations.rb', line 1853 def get_line_item(line_item_id:, **) path = interpolate_path("/line_items/{line_item_id}", line_item_id: line_item_id) get(path, **) end |
#get_plan(plan_id:, **options) ⇒ Resources::Plan
Fetch a plan
1980 1981 1982 1983 |
# File 'lib/recurly/client/operations.rb', line 1980 def get_plan(plan_id:, **) path = interpolate_path("/plans/{plan_id}", plan_id: plan_id) get(path, **) end |
#get_plan_add_on(plan_id:, add_on_id:, **options) ⇒ Resources::AddOn
Fetch a plan’s add-on
2089 2090 2091 2092 |
# File 'lib/recurly/client/operations.rb', line 2089 def get_plan_add_on(plan_id:, add_on_id:, **) path = interpolate_path("/plans/{plan_id}/add_ons/{add_on_id}", plan_id: plan_id, add_on_id: add_on_id) get(path, **) end |
#get_shipping_address(account_id:, shipping_address_id:, **options) ⇒ Resources::ShippingAddress
Fetch an account’s shipping address
874 875 876 877 |
# File 'lib/recurly/client/operations.rb', line 874 def get_shipping_address(account_id:, shipping_address_id:, **) path = interpolate_path("/accounts/{account_id}/shipping_addresses/{shipping_address_id}", account_id: account_id, shipping_address_id: shipping_address_id) get(path, **) end |
#get_shipping_method(id:, **options) ⇒ Resources::ShippingMethod
Fetch a shipping method
2211 2212 2213 2214 |
# File 'lib/recurly/client/operations.rb', line 2211 def get_shipping_method(id:, **) path = interpolate_path("/shipping_methods/{id}", id: id) get(path, **) end |
#get_site(site_id:) ⇒ Resources::Site
Fetch a site
51 52 53 54 |
# File 'lib/recurly/client/operations.rb', line 51 def get_site(site_id:) path = interpolate_path("/sites/{site_id}", site_id: site_id) get(path) end |
#get_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Fetch a subscription
2315 2316 2317 2318 |
# File 'lib/recurly/client/operations.rb', line 2315 def get_subscription(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}", subscription_id: subscription_id) get(path, **) end |
#get_subscription_change(subscription_id:, **options) ⇒ Resources::SubscriptionChange
Fetch a subscription’s pending change
2505 2506 2507 2508 |
# File 'lib/recurly/client/operations.rb', line 2505 def get_subscription_change(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/change", subscription_id: subscription_id) get(path, **) end |
#get_transaction(transaction_id:, **options) ⇒ Resources::Transaction
Fetch a transaction
2766 2767 2768 2769 |
# File 'lib/recurly/client/operations.rb', line 2766 def get_transaction(transaction_id:, **) path = interpolate_path("/transactions/{transaction_id}", transaction_id: transaction_id) get(path, **) end |
#get_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Fetch a unique coupon code
2778 2779 2780 2781 |
# File 'lib/recurly/client/operations.rb', line 2778 def get_unique_coupon_code(unique_coupon_code_id:, **) path = interpolate_path("/unique_coupon_codes/{unique_coupon_code_id}", unique_coupon_code_id: unique_coupon_code_id) get(path, **) end |
#list_account_acquisition(**options) ⇒ Pager<Resources::AccountAcquisition>
List a site’s account acquisition data
1122 1123 1124 1125 |
# File 'lib/recurly/client/operations.rb', line 1122 def list_account_acquisition(**) path = interpolate_path("/acquisitions") pager(path, **) end |
#list_account_coupon_redemptions(account_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions for an account
437 438 439 440 |
# File 'lib/recurly/client/operations.rb', line 437 def list_account_coupon_redemptions(account_id:, **) path = interpolate_path("/accounts/{account_id}/coupon_redemptions", account_id: account_id) pager(path, **) end |
#list_account_credit_payments(account_id:, **options) ⇒ Pager<Resources::CreditPayment>
List an account’s credit payments
544 545 546 547 |
# File 'lib/recurly/client/operations.rb', line 544 def list_account_credit_payments(account_id:, **) path = interpolate_path("/accounts/{account_id}/credit_payments", account_id: account_id) pager(path, **) end |
#list_account_invoices(account_id:, **options) ⇒ Pager<Resources::Invoice>
List an account’s invoices
595 596 597 598 |
# File 'lib/recurly/client/operations.rb', line 595 def list_account_invoices(account_id:, **) path = interpolate_path("/accounts/{account_id}/invoices", account_id: account_id) pager(path, **) end |
#list_account_line_items(account_id:, **options) ⇒ Pager<Resources::LineItem>
List an account’s line items
703 704 705 706 |
# File 'lib/recurly/client/operations.rb', line 703 def list_account_line_items(account_id:, **) path = interpolate_path("/accounts/{account_id}/line_items", account_id: account_id) pager(path, **) end |
#list_account_notes(account_id:, **options) ⇒ Pager<Resources::AccountNote>
Fetch a list of an account’s notes
764 765 766 767 |
# File 'lib/recurly/client/operations.rb', line 764 def list_account_notes(account_id:, **) path = interpolate_path("/accounts/{account_id}/notes", account_id: account_id) pager(path, **) end |
#list_account_subscriptions(account_id:, **options) ⇒ Pager<Resources::Subscription>
List an account’s subscriptions
984 985 986 987 |
# File 'lib/recurly/client/operations.rb', line 984 def list_account_subscriptions(account_id:, **) path = interpolate_path("/accounts/{account_id}/subscriptions", account_id: account_id) pager(path, **) end |
#list_account_transactions(account_id:, **options) ⇒ Pager<Resources::Transaction>
List an account’s transactions
1031 1032 1033 1034 |
# File 'lib/recurly/client/operations.rb', line 1031 def list_account_transactions(account_id:, **) path = interpolate_path("/accounts/{account_id}/transactions", account_id: account_id) pager(path, **) end |
#list_accounts(**options) ⇒ Pager<Resources::Account>
List a site’s accounts
97 98 99 100 |
# File 'lib/recurly/client/operations.rb', line 97 def list_accounts(**) path = interpolate_path("/accounts") pager(path, **) end |
#list_add_ons(**options) ⇒ Pager<Resources::AddOn>
List a site’s add-ons
2152 2153 2154 2155 |
# File 'lib/recurly/client/operations.rb', line 2152 def list_add_ons(**) path = interpolate_path("/add_ons") pager(path, **) end |
#list_child_accounts(account_id:, **options) ⇒ Pager<Resources::Account>
List an account’s child accounts
1081 1082 1083 1084 |
# File 'lib/recurly/client/operations.rb', line 1081 def list_child_accounts(account_id:, **) path = interpolate_path("/accounts/{account_id}/accounts", account_id: account_id) pager(path, **) end |
#list_coupons(**options) ⇒ Pager<Resources::Coupon>
List a site’s coupons
1163 1164 1165 1166 |
# File 'lib/recurly/client/operations.rb', line 1163 def list_coupons(**) path = interpolate_path("/coupons") pager(path, **) end |
#list_credit_payments(**options) ⇒ Pager<Resources::CreditPayment>
List a site’s credit payments
1298 1299 1300 1301 |
# File 'lib/recurly/client/operations.rb', line 1298 def list_credit_payments(**) path = interpolate_path("/credit_payments") pager(path, **) end |
#list_custom_field_definitions(**options) ⇒ Pager<Resources::CustomFieldDefinition>
List a site’s custom field definitions
1352 1353 1354 1355 |
# File 'lib/recurly/client/operations.rb', line 1352 def list_custom_field_definitions(**) path = interpolate_path("/custom_field_definitions") pager(path, **) end |
#list_invoice_coupon_redemptions(invoice_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions applied to an invoice
1751 1752 1753 1754 |
# File 'lib/recurly/client/operations.rb', line 1751 def list_invoice_coupon_redemptions(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/coupon_redemptions", invoice_id: invoice_id) pager(path, **) end |
#list_invoice_line_items(invoice_id:, **options) ⇒ Pager<Resources::LineItem>
List an invoice’s line items
1708 1709 1710 1711 |
# File 'lib/recurly/client/operations.rb', line 1708 def list_invoice_line_items(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/line_items", invoice_id: invoice_id) pager(path, **) end |
#list_invoices(**options) ⇒ Pager<Resources::Invoice>
List a site’s invoices
1508 1509 1510 1511 |
# File 'lib/recurly/client/operations.rb', line 1508 def list_invoices(**) path = interpolate_path("/invoices") pager(path, **) end |
#list_items(**options) ⇒ Pager<Resources::Item>
List a site’s items
1400 1401 1402 1403 |
# File 'lib/recurly/client/operations.rb', line 1400 def list_items(**) path = interpolate_path("/items") pager(path, **) end |
#list_line_items(**options) ⇒ Pager<Resources::LineItem>
List a site’s line items
1831 1832 1833 1834 |
# File 'lib/recurly/client/operations.rb', line 1831 def list_line_items(**) path = interpolate_path("/line_items") pager(path, **) end |
#list_plan_add_ons(plan_id:, **options) ⇒ Pager<Resources::AddOn>
List a plan’s add-ons
2051 2052 2053 2054 |
# File 'lib/recurly/client/operations.rb', line 2051 def list_plan_add_ons(plan_id:, **) path = interpolate_path("/plans/{plan_id}/add_ons", plan_id: plan_id) pager(path, **) end |
#list_plans(**options) ⇒ Pager<Resources::Plan>
List a site’s plans
1919 1920 1921 1922 |
# File 'lib/recurly/client/operations.rb', line 1919 def list_plans(**) path = interpolate_path("/plans") pager(path, **) end |
#list_related_invoices(invoice_id:, **options) ⇒ Pager<Resources::Invoice>
List an invoice’s related credit or charge invoices
1763 1764 1765 1766 |
# File 'lib/recurly/client/operations.rb', line 1763 def (invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/related_invoices", invoice_id: invoice_id) pager(path, **) end |
#list_shipping_addresses(account_id:, **options) ⇒ Pager<Resources::ShippingAddress>
Fetch a list of an account’s shipping addresses
835 836 837 838 |
# File 'lib/recurly/client/operations.rb', line 835 def list_shipping_addresses(account_id:, **) path = interpolate_path("/accounts/{account_id}/shipping_addresses", account_id: account_id) pager(path, **) end |
#list_shipping_methods(**options) ⇒ Pager<Resources::ShippingMethod>
List a site’s shipping methods
2199 2200 2201 2202 |
# File 'lib/recurly/client/operations.rb', line 2199 def list_shipping_methods(**) path = interpolate_path("/shipping_methods") pager(path, **) end |
#list_sites(**options) ⇒ Pager<Resources::Site>
List sites
40 41 42 43 |
# File 'lib/recurly/client/operations.rb', line 40 def list_sites(**) path = "/sites" pager(path, **) end |
#list_subscription_coupon_redemptions(subscription_id:, **options) ⇒ Pager<Resources::CouponRedemption>
Show the coupon redemptions for a subscription
2701 2702 2703 2704 |
# File 'lib/recurly/client/operations.rb', line 2701 def list_subscription_coupon_redemptions(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/coupon_redemptions", subscription_id: subscription_id) pager(path, **) end |
#list_subscription_invoices(subscription_id:, **options) ⇒ Pager<Resources::Invoice>
List a subscription’s invoices
2610 2611 2612 2613 |
# File 'lib/recurly/client/operations.rb', line 2610 def list_subscription_invoices(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/invoices", subscription_id: subscription_id) pager(path, **) end |
#list_subscription_line_items(subscription_id:, **options) ⇒ Pager<Resources::LineItem>
List a subscription’s line items
2658 2659 2660 2661 |
# File 'lib/recurly/client/operations.rb', line 2658 def list_subscription_line_items(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/line_items", subscription_id: subscription_id) pager(path, **) end |
#list_subscriptions(**options) ⇒ Pager<Resources::Subscription>
List a site’s subscriptions
2258 2259 2260 2261 |
# File 'lib/recurly/client/operations.rb', line 2258 def list_subscriptions(**) path = interpolate_path("/subscriptions") pager(path, **) end |
#list_transactions(**options) ⇒ Pager<Resources::Transaction>
List a site’s transactions
2744 2745 2746 2747 |
# File 'lib/recurly/client/operations.rb', line 2744 def list_transactions(**) path = interpolate_path("/transactions") pager(path, **) end |
#list_unique_coupon_codes(coupon_id:, **options) ⇒ Pager<Resources::UniqueCouponCode>
List unique coupon codes associated with a bulk coupon
1269 1270 1271 1272 |
# File 'lib/recurly/client/operations.rb', line 1269 def list_unique_coupon_codes(coupon_id:, **) path = interpolate_path("/coupons/{coupon_id}/unique_coupon_codes", coupon_id: coupon_id) pager(path, **) end |
#mark_invoice_successful(invoice_id:, **options) ⇒ Resources::Invoice
Mark an open invoice as successful
1635 1636 1637 1638 |
# File 'lib/recurly/client/operations.rb', line 1635 def mark_invoice_successful(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/mark_successful", invoice_id: invoice_id) put(path, **) end |
#modify_subscription(subscription_id:, body:, **options) ⇒ Resources::Subscription
Modify a subscription
2345 2346 2347 2348 |
# File 'lib/recurly/client/operations.rb', line 2345 def modify_subscription(subscription_id:, body:, **) path = interpolate_path("/subscriptions/{subscription_id}", subscription_id: subscription_id) put(path, body, Requests::SubscriptionUpdate, **) end |
#next_page(pager) ⇒ Object
52 53 54 55 56 |
# File 'lib/recurly/client.rb', line 52 def next_page(pager) req = HTTP::Request.new(:get, pager.next, nil) faraday_resp = run_request(req, headers) handle_response! req, faraday_resp end |
#pause_subscription(subscription_id:, body:, **options) ⇒ Resources::Subscription
Pause subscription
2457 2458 2459 2460 |
# File 'lib/recurly/client/operations.rb', line 2457 def pause_subscription(subscription_id:, body:, **) path = interpolate_path("/subscriptions/{subscription_id}/pause", subscription_id: subscription_id) put(path, body, Requests::SubscriptionPause, **) end |
#preview_invoice(account_id:, body:, **options) ⇒ Resources::InvoiceCollection
Preview new invoice for pending line items
655 656 657 658 |
# File 'lib/recurly/client/operations.rb', line 655 def preview_invoice(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/invoices/preview", account_id: account_id) post(path, body, Requests::InvoiceCreate, **) end |
#preview_purchase(body:, **options) ⇒ Resources::InvoiceCollection
Preview a new purchase
2880 2881 2882 2883 |
# File 'lib/recurly/client/operations.rb', line 2880 def preview_purchase(body:, **) path = interpolate_path("/purchases/preview") post(path, body, Requests::PurchaseCreate, **) end |
#put_invoice(invoice_id:, body:, **options) ⇒ Resources::Invoice
Update an invoice
1543 1544 1545 1546 |
# File 'lib/recurly/client/operations.rb', line 1543 def put_invoice(invoice_id:, body:, **) path = interpolate_path("/invoices/{invoice_id}", invoice_id: invoice_id) put(path, body, Requests::InvoiceUpdatable, **) end |
#reactivate_account(account_id:, **options) ⇒ Resources::Account
Reactivate an inactive account
298 299 300 301 |
# File 'lib/recurly/client/operations.rb', line 298 def reactivate_account(account_id:, **) path = interpolate_path("/accounts/{account_id}/reactivate", account_id: account_id) put(path, **) end |
#reactivate_item(item_id:, **options) ⇒ Resources::Item
Reactivate an inactive item
1461 1462 1463 1464 |
# File 'lib/recurly/client/operations.rb', line 1461 def reactivate_item(item_id:, **) path = interpolate_path("/items/{item_id}/reactivate", item_id: item_id) put(path, **) end |
#reactivate_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Reactivate a canceled subscription
2428 2429 2430 2431 |
# File 'lib/recurly/client/operations.rb', line 2428 def reactivate_subscription(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/reactivate", subscription_id: subscription_id) put(path, **) end |
#reactivate_unique_coupon_code(unique_coupon_code_id:, **options) ⇒ Resources::UniqueCouponCode
Restore a unique coupon code
2802 2803 2804 2805 |
# File 'lib/recurly/client/operations.rb', line 2802 def reactivate_unique_coupon_code(unique_coupon_code_id:, **) path = interpolate_path("/unique_coupon_codes/{unique_coupon_code_id}/restore", unique_coupon_code_id: unique_coupon_code_id) put(path, **) end |
#refund_invoice(invoice_id:, body:, **options) ⇒ Resources::Invoice
Refund an invoice
1793 1794 1795 1796 |
# File 'lib/recurly/client/operations.rb', line 1793 def refund_invoice(invoice_id:, body:, **) path = interpolate_path("/invoices/{invoice_id}/refund", invoice_id: invoice_id) post(path, body, Requests::InvoiceRefund, **) end |
#remove_account_acquisition(account_id:, **options) ⇒ Empty
Remove an account’s acquisition data
276 277 278 279 |
# File 'lib/recurly/client/operations.rb', line 276 def remove_account_acquisition(account_id:, **) path = interpolate_path("/accounts/{account_id}/acquisition", account_id: account_id) delete(path, **) end |
#remove_billing_info(account_id:, **options) ⇒ Empty
Remove an account’s billing information
394 395 396 397 |
# File 'lib/recurly/client/operations.rb', line 394 def remove_billing_info(account_id:, **) path = interpolate_path("/accounts/{account_id}/billing_info", account_id: account_id) delete(path, **) end |
#remove_coupon_redemption(account_id:, **options) ⇒ Resources::CouponRedemption
Delete the active coupon redemption from an account
511 512 513 514 |
# File 'lib/recurly/client/operations.rb', line 511 def remove_coupon_redemption(account_id:, **) path = interpolate_path("/accounts/{account_id}/coupon_redemptions/active", account_id: account_id) delete(path, **) end |
#remove_line_item(line_item_id:, **options) ⇒ Empty
Delete an uninvoiced line item
1877 1878 1879 1880 |
# File 'lib/recurly/client/operations.rb', line 1877 def remove_line_item(line_item_id:, **) path = interpolate_path("/line_items/{line_item_id}", line_item_id: line_item_id) delete(path, **) end |
#remove_plan(plan_id:, **options) ⇒ Resources::Plan
Remove a plan
2005 2006 2007 2008 |
# File 'lib/recurly/client/operations.rb', line 2005 def remove_plan(plan_id:, **) path = interpolate_path("/plans/{plan_id}", plan_id: plan_id) delete(path, **) end |
#remove_plan_add_on(plan_id:, add_on_id:, **options) ⇒ Resources::AddOn
Remove an add-on
2116 2117 2118 2119 |
# File 'lib/recurly/client/operations.rb', line 2116 def remove_plan_add_on(plan_id:, add_on_id:, **) path = interpolate_path("/plans/{plan_id}/add_ons/{add_on_id}", plan_id: plan_id, add_on_id: add_on_id) delete(path, **) end |
#remove_shipping_address(account_id:, shipping_address_id:, **options) ⇒ Empty
Remove an account’s shipping address
933 934 935 936 |
# File 'lib/recurly/client/operations.rb', line 933 def remove_shipping_address(account_id:, shipping_address_id:, **) path = interpolate_path("/accounts/{account_id}/shipping_addresses/{shipping_address_id}", account_id: account_id, shipping_address_id: shipping_address_id) delete(path, **) end |
#remove_subscription_change(subscription_id:, **options) ⇒ Empty
Delete the pending subscription change
2559 2560 2561 2562 |
# File 'lib/recurly/client/operations.rb', line 2559 def remove_subscription_change(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/change", subscription_id: subscription_id) delete(path, **) end |
#reopen_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Reopen a closed, manual invoice
1657 1658 1659 1660 |
# File 'lib/recurly/client/operations.rb', line 1657 def reopen_invoice(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/reopen", invoice_id: invoice_id) put(path, **) end |
#resume_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Resume subscription
2481 2482 2483 2484 |
# File 'lib/recurly/client/operations.rb', line 2481 def resume_subscription(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}/resume", subscription_id: subscription_id) put(path, **) end |
#terminate_subscription(subscription_id:, **options) ⇒ Resources::Subscription
Terminate a subscription
2379 2380 2381 2382 |
# File 'lib/recurly/client/operations.rb', line 2379 def terminate_subscription(subscription_id:, **) path = interpolate_path("/subscriptions/{subscription_id}", subscription_id: subscription_id) delete(path, **) end |
#update_account(account_id:, body:, **options) ⇒ Resources::Account
Modify an account
197 198 199 200 |
# File 'lib/recurly/client/operations.rb', line 197 def update_account(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}", account_id: account_id) put(path, body, Requests::AccountUpdate, **) end |
#update_account_acquisition(account_id:, body:, **options) ⇒ Resources::AccountAcquisition
Update an account’s acquisition data
254 255 256 257 |
# File 'lib/recurly/client/operations.rb', line 254 def update_account_acquisition(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/acquisition", account_id: account_id) put(path, body, Requests::AccountAcquisitionUpdatable, **) end |
#update_billing_info(account_id:, body:, **options) ⇒ Resources::BillingInfo
Set an account’s billing information
372 373 374 375 |
# File 'lib/recurly/client/operations.rb', line 372 def update_billing_info(account_id:, body:, **) path = interpolate_path("/accounts/{account_id}/billing_info", account_id: account_id) put(path, body, Requests::BillingInfoCreate, **) end |
#update_coupon(coupon_id:, body:, **options) ⇒ Resources::Coupon
Update an active coupon
1233 1234 1235 1236 |
# File 'lib/recurly/client/operations.rb', line 1233 def update_coupon(coupon_id:, body:, **) path = interpolate_path("/coupons/{coupon_id}", coupon_id: coupon_id) put(path, body, Requests::CouponUpdate, **) end |
#update_item(item_id:, body:, **options) ⇒ Resources::Item
Update an active item
1437 1438 1439 1440 |
# File 'lib/recurly/client/operations.rb', line 1437 def update_item(item_id:, body:, **) path = interpolate_path("/items/{item_id}", item_id: item_id) put(path, body, Requests::ItemUpdate, **) end |
#update_plan(plan_id:, body:, **options) ⇒ Resources::Plan
Update a plan
1993 1994 1995 1996 |
# File 'lib/recurly/client/operations.rb', line 1993 def update_plan(plan_id:, body:, **) path = interpolate_path("/plans/{plan_id}", plan_id: plan_id) put(path, body, Requests::PlanUpdate, **) end |
#update_plan_add_on(plan_id:, add_on_id:, body:, **options) ⇒ Resources::AddOn
Update an add-on
2103 2104 2105 2106 |
# File 'lib/recurly/client/operations.rb', line 2103 def update_plan_add_on(plan_id:, add_on_id:, body:, **) path = interpolate_path("/plans/{plan_id}/add_ons/{add_on_id}", plan_id: plan_id, add_on_id: add_on_id) put(path, body, Requests::AddOnUpdate, **) end |
#update_shipping_address(account_id:, shipping_address_id:, body:, **options) ⇒ Resources::ShippingAddress
Update an account’s shipping address
907 908 909 910 |
# File 'lib/recurly/client/operations.rb', line 907 def update_shipping_address(account_id:, shipping_address_id:, body:, **) path = interpolate_path("/accounts/{account_id}/shipping_addresses/{shipping_address_id}", account_id: account_id, shipping_address_id: shipping_address_id) put(path, body, Requests::ShippingAddressUpdate, **) end |
#void_invoice(invoice_id:, **options) ⇒ Resources::Invoice
Void a credit invoice.
1669 1670 1671 1672 |
# File 'lib/recurly/client/operations.rb', line 1669 def void_invoice(invoice_id:, **) path = interpolate_path("/invoices/{invoice_id}/void", invoice_id: invoice_id) put(path, **) end |