Class: Recurly::Requests::AddOnUpdate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/add_on_update.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#accounting_codeString

Returns Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.

Returns:

  • (String)

    Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.



11
# File 'lib/recurly/requests/add_on_update.rb', line 11

define_attribute :accounting_code, String

#codeString

Returns The unique identifier for the add-on within its plan.

Returns:

  • (String)

    The unique identifier for the add-on within its plan.



15
# File 'lib/recurly/requests/add_on_update.rb', line 15

define_attribute :code, String

#currenciesArray[AddOnPricing]

Returns Add-on pricing.

Returns:



19
# File 'lib/recurly/requests/add_on_update.rb', line 19

define_attribute :currencies, Array, { :item_type => :AddOnPricing }

#default_quantityInteger

Returns Default quantity for the hosted pages.

Returns:

  • (Integer)

    Default quantity for the hosted pages.



23
# File 'lib/recurly/requests/add_on_update.rb', line 23

define_attribute :default_quantity, Integer

#display_quantityBoolean

Returns Determines if the quantity field is displayed on the hosted pages for the add-on.

Returns:

  • (Boolean)

    Determines if the quantity field is displayed on the hosted pages for the add-on.



27
# File 'lib/recurly/requests/add_on_update.rb', line 27

define_attribute :display_quantity, :Boolean

#idString

Returns Add-on ID.

Returns:

  • (String)

    Add-on ID



31
# File 'lib/recurly/requests/add_on_update.rb', line 31

define_attribute :id, String

#nameString

Returns Describes your add-on and will appear in subscribers’ invoices.

Returns:

  • (String)

    Describes your add-on and will appear in subscribers’ invoices.



35
# File 'lib/recurly/requests/add_on_update.rb', line 35

define_attribute :name, String

#tax_codeString

Returns Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules. If you have your own AvaTax or Vertex account configured, use their tax codes to assign specific tax rules. If you are using Recurly’s EU VAT feature, you can use values of unknown, physical, or digital.

Returns:

  • (String)

    Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules. If you have your own AvaTax or Vertex account configured, use their tax codes to assign specific tax rules. If you are using Recurly’s EU VAT feature, you can use values of unknown, physical, or digital.



39
# File 'lib/recurly/requests/add_on_update.rb', line 39

define_attribute :tax_code, String