Class: Recurly::Requests::BillingInfoCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::BillingInfoCreate
- Defined in:
- lib/recurly/requests/billing_info_create.rb
Instance Attribute Summary collapse
-
#account_number ⇒ String
The bank account number.
-
#account_type ⇒ String
The bank account type.
- #address ⇒ Address
-
#adyen_risk_profile_reference_id ⇒ String
The Adyen Risk Profile Reference ID is used to identify the risk profile for the payment method.
-
#amazon_billing_agreement_id ⇒ String
Only supported on Amazon V1.
-
#backup_payment_method ⇒ Boolean
The
backup_payment_methodfield is used to designate a billing info as a backup on the account that will be tried if the initial billing info used for an invoice is declined. -
#card_network_preference ⇒ String
Represents the card network preference associated with the billing info for dual badged cards.
- #card_type ⇒ String
-
#company ⇒ String
Company name.
-
#currency ⇒ String
3-letter ISO 4217 currency code.
-
#cvv ⇒ String
*STRONGLY RECOMMENDED*.
-
#external_hpp_type ⇒ String
Use for Adyen HPP billing info.
-
#first_name ⇒ String
First name.
-
#fraud_session_id ⇒ String
Fraud Session ID.
-
#gateway_attributes ⇒ GatewayAttributes
Additional attributes to send to the gateway.
-
#gateway_code ⇒ String
An identifier for a specific payment gateway.
-
#gateway_token ⇒ String
A token used in place of a credit card in order to perform transactions.
-
#iban ⇒ String
The International Bank Account Number, up to 34 alphanumeric characters comprising a country code; two check digits; and a number that includes the domestic bank account number, branch identifier, and potential routing information.
-
#ip_address ⇒ String
*STRONGLY RECOMMENDED* Customer’s IP address when updating their billing information.
-
#last_name ⇒ String
Last name.
-
#month ⇒ String
Expiration month.
-
#name_on_account ⇒ String
The name associated with the bank account (ACH, SEPA, Bacs only).
-
#number ⇒ String
Credit card number, spaces and dashes are accepted.
-
#online_banking_payment_type ⇒ String
Use for Online Banking billing info.
-
#payment_gateway_references ⇒ Array[PaymentGatewayReferences]
Array of Payment Gateway References, each a reference to a third-party gateway object of varying types.
-
#paypal_billing_agreement_id ⇒ String
PayPal billing agreement ID.
-
#primary_payment_method ⇒ Boolean
The
primary_payment_methodfield is used to designate the primary billing info on the account. -
#return_url ⇒ String
Specifies a URL to which a consumer will be redirected upon completion of a redirect payment flow.
-
#roku_billing_agreement_id ⇒ String
Roku’s CIB if billing through Roku.
-
#routing_number ⇒ String
The bank’s rounting number.
-
#sort_code ⇒ String
Bank identifier code for UK based banks.
-
#tax_identifier ⇒ String
Tax identifier is required if adding a billing info that is a consumer card in Brazil or in Argentina.
-
#tax_identifier_type ⇒ String
This field and a value of
cpf,cnpjorcuitare required if adding a billing info that is an elo or hipercard type in Brazil or in Argentina. -
#three_d_secure_action_result_token_id ⇒ String
A token generated by Recurly.js after completing a 3-D Secure device fingerprinting or authentication challenge.
-
#token_id ⇒ String
A token [generated by Recurly.js](recurly.com/developers/reference/recurly-js/#getting-a-token).
-
#transaction_type ⇒ String
An optional type designation for the payment gateway transaction created by this request.
-
#type ⇒ String
The payment method type for a non-credit card based billing info.
-
#vat_number ⇒ String
VAT number.
-
#year ⇒ String
Expiration year.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#account_number ⇒ String
11 |
# File 'lib/recurly/requests/billing_info_create.rb', line 11 define_attribute :account_number, String |
#account_type ⇒ String
15 |
# File 'lib/recurly/requests/billing_info_create.rb', line 15 define_attribute :account_type, String |
#address ⇒ Address
19 |
# File 'lib/recurly/requests/billing_info_create.rb', line 19 define_attribute :address, :Address |
#adyen_risk_profile_reference_id ⇒ String
23 |
# File 'lib/recurly/requests/billing_info_create.rb', line 23 define_attribute :adyen_risk_profile_reference_id, String |
#amazon_billing_agreement_id ⇒ String
27 |
# File 'lib/recurly/requests/billing_info_create.rb', line 27 define_attribute :amazon_billing_agreement_id, String |
#backup_payment_method ⇒ Boolean
31 |
# File 'lib/recurly/requests/billing_info_create.rb', line 31 define_attribute :backup_payment_method, :Boolean |
#card_network_preference ⇒ String
35 |
# File 'lib/recurly/requests/billing_info_create.rb', line 35 define_attribute :card_network_preference, String |
#card_type ⇒ String
39 |
# File 'lib/recurly/requests/billing_info_create.rb', line 39 define_attribute :card_type, String |
#company ⇒ String
43 |
# File 'lib/recurly/requests/billing_info_create.rb', line 43 define_attribute :company, String |
#currency ⇒ String
47 |
# File 'lib/recurly/requests/billing_info_create.rb', line 47 define_attribute :currency, String |
#cvv ⇒ String
51 |
# File 'lib/recurly/requests/billing_info_create.rb', line 51 define_attribute :cvv, String |
#external_hpp_type ⇒ String
55 |
# File 'lib/recurly/requests/billing_info_create.rb', line 55 define_attribute :external_hpp_type, String |
#first_name ⇒ String
59 |
# File 'lib/recurly/requests/billing_info_create.rb', line 59 define_attribute :first_name, String |
#fraud_session_id ⇒ String
63 |
# File 'lib/recurly/requests/billing_info_create.rb', line 63 define_attribute :fraud_session_id, String |
#gateway_attributes ⇒ GatewayAttributes
67 |
# File 'lib/recurly/requests/billing_info_create.rb', line 67 define_attribute :gateway_attributes, :GatewayAttributes |
#gateway_code ⇒ String
71 |
# File 'lib/recurly/requests/billing_info_create.rb', line 71 define_attribute :gateway_code, String |
#gateway_token ⇒ String
75 |
# File 'lib/recurly/requests/billing_info_create.rb', line 75 define_attribute :gateway_token, String |
#iban ⇒ String
79 |
# File 'lib/recurly/requests/billing_info_create.rb', line 79 define_attribute :iban, String |
#ip_address ⇒ String
83 |
# File 'lib/recurly/requests/billing_info_create.rb', line 83 define_attribute :ip_address, String |
#last_name ⇒ String
87 |
# File 'lib/recurly/requests/billing_info_create.rb', line 87 define_attribute :last_name, String |
#month ⇒ String
91 |
# File 'lib/recurly/requests/billing_info_create.rb', line 91 define_attribute :month, String |
#name_on_account ⇒ String
95 |
# File 'lib/recurly/requests/billing_info_create.rb', line 95 define_attribute :name_on_account, String |
#number ⇒ String
99 |
# File 'lib/recurly/requests/billing_info_create.rb', line 99 define_attribute :number, String |
#online_banking_payment_type ⇒ String
103 |
# File 'lib/recurly/requests/billing_info_create.rb', line 103 define_attribute :online_banking_payment_type, String |
#payment_gateway_references ⇒ Array[PaymentGatewayReferences]
107 |
# File 'lib/recurly/requests/billing_info_create.rb', line 107 define_attribute :payment_gateway_references, Array, { :item_type => :PaymentGatewayReferences } |
#paypal_billing_agreement_id ⇒ String
111 |
# File 'lib/recurly/requests/billing_info_create.rb', line 111 define_attribute :paypal_billing_agreement_id, String |
#primary_payment_method ⇒ Boolean
115 |
# File 'lib/recurly/requests/billing_info_create.rb', line 115 define_attribute :primary_payment_method, :Boolean |
#return_url ⇒ String
119 |
# File 'lib/recurly/requests/billing_info_create.rb', line 119 define_attribute :return_url, String |
#roku_billing_agreement_id ⇒ String
123 |
# File 'lib/recurly/requests/billing_info_create.rb', line 123 define_attribute :roku_billing_agreement_id, String |
#routing_number ⇒ String
127 |
# File 'lib/recurly/requests/billing_info_create.rb', line 127 define_attribute :routing_number, String |
#sort_code ⇒ String
131 |
# File 'lib/recurly/requests/billing_info_create.rb', line 131 define_attribute :sort_code, String |
#tax_identifier ⇒ String
135 |
# File 'lib/recurly/requests/billing_info_create.rb', line 135 define_attribute :tax_identifier, String |
#tax_identifier_type ⇒ String
139 |
# File 'lib/recurly/requests/billing_info_create.rb', line 139 define_attribute :tax_identifier_type, String |
#three_d_secure_action_result_token_id ⇒ String
143 |
# File 'lib/recurly/requests/billing_info_create.rb', line 143 define_attribute :three_d_secure_action_result_token_id, String |
#token_id ⇒ String
147 |
# File 'lib/recurly/requests/billing_info_create.rb', line 147 define_attribute :token_id, String |
#transaction_type ⇒ String
151 |
# File 'lib/recurly/requests/billing_info_create.rb', line 151 define_attribute :transaction_type, String |
#type ⇒ String
155 |
# File 'lib/recurly/requests/billing_info_create.rb', line 155 define_attribute :type, String |
#vat_number ⇒ String
159 |
# File 'lib/recurly/requests/billing_info_create.rb', line 159 define_attribute :vat_number, String |
#year ⇒ String
163 |
# File 'lib/recurly/requests/billing_info_create.rb', line 163 define_attribute :year, String |