Class: Recurly::Requests::CreditApplicationPolicy

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/credit_application_policy.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#allowed_originsArray[String]

Returns Optional array of credit invoice origin types to allow when mode is all. If not specified when mode is all, credits from all origins are applied. Only valid when mode is all.

Returns:

  • (Array[String])

    Optional array of credit invoice origin types to allow when mode is all. If not specified when mode is all, credits from all origins are applied. Only valid when mode is all.



11
# File 'lib/recurly/requests/credit_application_policy.rb', line 11

define_attribute :allowed_origins, Array, { :item_type => String }

#modeString

Returns Determines which credit invoices are applied to invoices: - all: All available credit invoices are applied (default) - none: No credit invoices are applied automatically.

Returns:

  • (String)

    Determines which credit invoices are applied to invoices: - all: All available credit invoices are applied (default) - none: No credit invoices are applied automatically



15
# File 'lib/recurly/requests/credit_application_policy.rb', line 15

define_attribute :mode, String