Class: Recurly::Requests::InvoiceCollect
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::InvoiceCollect
- Defined in:
- lib/recurly/requests/invoice_collect.rb
Instance Attribute Summary collapse
-
#billing_info_id ⇒ String
The
billing_info_idis the value that represents a specific billing info for an end customer. -
#three_d_secure_action_result_token_id ⇒ String
A token generated by Recurly.js after completing a 3-D Secure device fingerprinting or authentication challenge.
-
#transaction_type ⇒ String
An optional type designation for the payment gateway transaction created by this request.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#billing_info_id ⇒ String
11 |
# File 'lib/recurly/requests/invoice_collect.rb', line 11 define_attribute :billing_info_id, String |
#three_d_secure_action_result_token_id ⇒ String
15 |
# File 'lib/recurly/requests/invoice_collect.rb', line 15 define_attribute :three_d_secure_action_result_token_id, String |
#transaction_type ⇒ String
19 |
# File 'lib/recurly/requests/invoice_collect.rb', line 19 define_attribute :transaction_type, String |