Class: Recurly::Requests::InvoiceCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/invoice_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#business_entity_codeString

Returns The business_entity_code is the value that represents a specific business entity for an end customer which will be assigned to the invoice. Available when the ‘Multiple Business Entities` feature is enabled. If both business_entity_id and business_entity_code are present, business_entity_id will be used.

Returns:

  • (String)

    The business_entity_code is the value that represents a specific business entity for an end customer which will be assigned to the invoice. Available when the ‘Multiple Business Entities` feature is enabled. If both business_entity_id and business_entity_code are present, business_entity_id will be used.



11
# File 'lib/recurly/requests/invoice_create.rb', line 11

define_attribute :business_entity_code, String

#business_entity_idString

Returns The business_entity_id is the value that represents a specific business entity for an end customer which will be assigned to the invoice. Available when the ‘Multiple Business Entities` feature is enabled. If both business_entity_id and business_entity_code are present, business_entity_id will be used.

Returns:

  • (String)

    The business_entity_id is the value that represents a specific business entity for an end customer which will be assigned to the invoice. Available when the ‘Multiple Business Entities` feature is enabled. If both business_entity_id and business_entity_code are present, business_entity_id will be used.



15
# File 'lib/recurly/requests/invoice_create.rb', line 15

define_attribute :business_entity_id, String

#charge_customer_notesString

Returns This will default to the Customer Notes text specified on the Invoice Settings for charge invoices. Specify custom notes to add or override Customer Notes on charge invoices.

Returns:

  • (String)

    This will default to the Customer Notes text specified on the Invoice Settings for charge invoices. Specify custom notes to add or override Customer Notes on charge invoices.



19
# File 'lib/recurly/requests/invoice_create.rb', line 19

define_attribute :charge_customer_notes, String

#collection_methodString

Returns An automatic invoice means a corresponding transaction is run using the account’s billing information at the same time the invoice is created. Manual invoices are created without a corresponding transaction. The merchant must enter a manual payment transaction or have the customer pay the invoice with an automatic method, like credit card, PayPal, Amazon, or ACH bank payment.

Returns:

  • (String)

    An automatic invoice means a corresponding transaction is run using the account’s billing information at the same time the invoice is created. Manual invoices are created without a corresponding transaction. The merchant must enter a manual payment transaction or have the customer pay the invoice with an automatic method, like credit card, PayPal, Amazon, or ACH bank payment.



23
# File 'lib/recurly/requests/invoice_create.rb', line 23

define_attribute :collection_method, String

#credit_application_policyCreditApplicationPolicy

Returns Controls whether credit invoices are automatically applied to new invoices. The mode field determines the application behavior. When mode is all, the optional allowed_origins array can restrict which credit invoice origins are applied.

Returns:

  • (CreditApplicationPolicy)

    Controls whether credit invoices are automatically applied to new invoices. The mode field determines the application behavior. When mode is all, the optional allowed_origins array can restrict which credit invoice origins are applied.



27
# File 'lib/recurly/requests/invoice_create.rb', line 27

define_attribute :credit_application_policy, :CreditApplicationPolicy

#credit_customer_notesString

Returns This will default to the Customer Notes text specified on the Invoice Settings for credit invoices. Specify customer notes to add or override Customer Notes on credit invoices.

Returns:

  • (String)

    This will default to the Customer Notes text specified on the Invoice Settings for credit invoices. Specify customer notes to add or override Customer Notes on credit invoices.



31
# File 'lib/recurly/requests/invoice_create.rb', line 31

define_attribute :credit_customer_notes, String

#currencyString

Returns 3-letter ISO 4217 currency code.

Returns:

  • (String)

    3-letter ISO 4217 currency code.



35
# File 'lib/recurly/requests/invoice_create.rb', line 35

define_attribute :currency, String

#net_termsInteger

Returns Integer paired with ‘Net Terms Type` and representing the number of days past the current date (for net Net Terms Type) or days after the last day of the current month (for eom Net Terms Type) that the invoice will become past due. For manual collection method, an additional 24 hours is added to ensure the customer has the entire last day to make payment before becoming past due. For example: If an invoice is due `net 0`, it is due ’On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due ‘net 30`, it will become past due at 31 days exactly. If an invoice is due `eom 30`, it will become past due 31 days from the last day of the current month. For automatic collection method, the additional 24 hours is not added. For example, On-Receipt is due immediately, and `net 30` will become due exactly 30 days from invoice generation, at which point Recurly will attempt collection. When eom Net Terms Type is passed, the value for `Net Terms` is restricted to `0, 15, 30, 45, 60, or 90`. For more information on how net terms work with manual collection visit our docs page (docs.recurly.com/docs/manual-payments#section-collection-terms) or visit (docs.recurly.com/docs/automatic-invoicing-terms#section-collection-terms) for information about net terms using automatic collection.

Returns:

  • (Integer)

    Integer paired with ‘Net Terms Type` and representing the number of days past the current date (for net Net Terms Type) or days after the last day of the current month (for eom Net Terms Type) that the invoice will become past due. For manual collection method, an additional 24 hours is added to ensure the customer has the entire last day to make payment before becoming past due. For example: If an invoice is due `net 0`, it is due ’On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due ‘net 30`, it will become past due at 31 days exactly. If an invoice is due `eom 30`, it will become past due 31 days from the last day of the current month. For automatic collection method, the additional 24 hours is not added. For example, On-Receipt is due immediately, and `net 30` will become due exactly 30 days from invoice generation, at which point Recurly will attempt collection. When eom Net Terms Type is passed, the value for `Net Terms` is restricted to `0, 15, 30, 45, 60, or 90`. For more information on how net terms work with manual collection visit our docs page (docs.recurly.com/docs/manual-payments#section-collection-terms) or visit (docs.recurly.com/docs/automatic-invoicing-terms#section-collection-terms) for information about net terms using automatic collection.



39
# File 'lib/recurly/requests/invoice_create.rb', line 39

define_attribute :net_terms, Integer

#net_terms_typeString

Returns Optionally supplied string that may be either net or eom (end-of-month). When net, an invoice becomes past due the specified number of ‘Net Terms` days from the current date. When eom an invoice becomes past due the specified number of `Net Terms` days from the last day of the current month.

Returns:

  • (String)

    Optionally supplied string that may be either net or eom (end-of-month). When net, an invoice becomes past due the specified number of ‘Net Terms` days from the current date. When eom an invoice becomes past due the specified number of `Net Terms` days from the last day of the current month.



43
# File 'lib/recurly/requests/invoice_create.rb', line 43

define_attribute :net_terms_type, String

#po_numberString

Returns For manual invoicing, this identifies the PO number associated with the subscription.

Returns:

  • (String)

    For manual invoicing, this identifies the PO number associated with the subscription.



47
# File 'lib/recurly/requests/invoice_create.rb', line 47

define_attribute :po_number, String

#terms_and_conditionsString

Returns This will default to the Terms and Conditions text specified on the Invoice Settings page in your Recurly admin. Specify custom notes to add or override Terms and Conditions.

Returns:

  • (String)

    This will default to the Terms and Conditions text specified on the Invoice Settings page in your Recurly admin. Specify custom notes to add or override Terms and Conditions.



51
# File 'lib/recurly/requests/invoice_create.rb', line 51

define_attribute :terms_and_conditions, String

#vat_reverse_charge_notesString

Returns VAT Reverse Charge Notes only appear if you have EU VAT enabled or are using your own Avalara AvaTax account and the customer is in the EU, has a VAT number, and is in a different country than your own. This will default to the VAT Reverse Charge Notes text specified on the Tax Settings page in your Recurly admin, unless custom notes were created with the original subscription.

Returns:

  • (String)

    VAT Reverse Charge Notes only appear if you have EU VAT enabled or are using your own Avalara AvaTax account and the customer is in the EU, has a VAT number, and is in a different country than your own. This will default to the VAT Reverse Charge Notes text specified on the Tax Settings page in your Recurly admin, unless custom notes were created with the original subscription.



55
# File 'lib/recurly/requests/invoice_create.rb', line 55

define_attribute :vat_reverse_charge_notes, String

#vertex_transaction_typeString

Returns Used by Vertex for tax calculations. Possible values are sale, rental, lease.

Returns:

  • (String)

    Used by Vertex for tax calculations. Possible values are sale, rental, lease.



59
# File 'lib/recurly/requests/invoice_create.rb', line 59

define_attribute :vertex_transaction_type, String