Class: Recurly::Requests::ItemCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/item_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#accounting_codeString

Returns Accounting code for invoice line items.

Returns:

  • (String)

    Accounting code for invoice line items.



11
# File 'lib/recurly/requests/item_create.rb', line 11

define_attribute :accounting_code, String

#codeString

Returns Unique code to identify the item.

Returns:

  • (String)

    Unique code to identify the item.



15
# File 'lib/recurly/requests/item_create.rb', line 15

define_attribute :code, String

#currenciesArray[Pricing]

Returns Item Pricing.

Returns:

  • (Array[Pricing])

    Item Pricing



19
# File 'lib/recurly/requests/item_create.rb', line 19

define_attribute :currencies, Array, { :item_type => :Pricing }

#custom_fieldsArray[CustomField]

Returns:



23
# File 'lib/recurly/requests/item_create.rb', line 23

define_attribute :custom_fields, Array, { :item_type => :CustomField }

#descriptionString

Returns Optional, description.

Returns:

  • (String)

    Optional, description.



27
# File 'lib/recurly/requests/item_create.rb', line 27

define_attribute :description, String

#external_skuString

Returns Optional, stock keeping unit to link the item to other inventory systems.

Returns:

  • (String)

    Optional, stock keeping unit to link the item to other inventory systems.



31
# File 'lib/recurly/requests/item_create.rb', line 31

define_attribute :external_sku, String

#nameString

Returns This name describes your item and will appear on the invoice when it’s purchased on a one time basis.

Returns:

  • (String)

    This name describes your item and will appear on the invoice when it’s purchased on a one time basis.



35
# File 'lib/recurly/requests/item_create.rb', line 35

define_attribute :name, String

#revenue_schedule_typeString

Returns Revenue schedule type.

Returns:

  • (String)

    Revenue schedule type



39
# File 'lib/recurly/requests/item_create.rb', line 39

define_attribute :revenue_schedule_type, String

#tax_codeString

Returns Used by Avalara, Vertex, and Recurly’s EU VAT tax feature. The tax code values are specific to each tax system. If you are using Recurly’s EU VAT feature you can use unknown, physical, or digital.

Returns:

  • (String)

    Used by Avalara, Vertex, and Recurly’s EU VAT tax feature. The tax code values are specific to each tax system. If you are using Recurly’s EU VAT feature you can use unknown, physical, or digital.



43
# File 'lib/recurly/requests/item_create.rb', line 43

define_attribute :tax_code, String

#tax_exemptBoolean

Returns true exempts tax on the item, false applies tax on the item.

Returns:

  • (Boolean)

    true exempts tax on the item, false applies tax on the item.



47
# File 'lib/recurly/requests/item_create.rb', line 47

define_attribute :tax_exempt, :Boolean