Class: Recurly::Requests::ItemUpdate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::ItemUpdate
- Defined in:
- lib/recurly/requests/item_update.rb
Instance Attribute Summary collapse
-
#accounting_code ⇒ String
Accounting code for invoice line items.
-
#code ⇒ String
Unique code to identify the item.
-
#currencies ⇒ Array[Pricing]
Item Pricing.
- #custom_fields ⇒ Array[CustomField]
-
#description ⇒ String
Optional, description.
-
#external_sku ⇒ String
Optional, stock keeping unit to link the item to other inventory systems.
-
#name ⇒ String
This name describes your item and will appear on the invoice when it’s purchased on a one time basis.
-
#revenue_schedule_type ⇒ String
Revenue schedule type.
-
#tax_code ⇒ String
Used by Avalara, Vertex, and Recurly’s EU VAT tax feature.
-
#tax_exempt ⇒ Boolean
trueexempts tax on the item,falseapplies tax on the item.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#accounting_code ⇒ String
Returns Accounting code for invoice line items.
11 |
# File 'lib/recurly/requests/item_update.rb', line 11 define_attribute :accounting_code, String |
#code ⇒ String
Returns Unique code to identify the item.
15 |
# File 'lib/recurly/requests/item_update.rb', line 15 define_attribute :code, String |
#currencies ⇒ Array[Pricing]
Returns Item Pricing.
19 |
# File 'lib/recurly/requests/item_update.rb', line 19 define_attribute :currencies, Array, { :item_type => :Pricing } |
#custom_fields ⇒ Array[CustomField]
23 |
# File 'lib/recurly/requests/item_update.rb', line 23 define_attribute :custom_fields, Array, { :item_type => :CustomField } |
#description ⇒ String
Returns Optional, description.
27 |
# File 'lib/recurly/requests/item_update.rb', line 27 define_attribute :description, String |
#external_sku ⇒ String
Returns Optional, stock keeping unit to link the item to other inventory systems.
31 |
# File 'lib/recurly/requests/item_update.rb', line 31 define_attribute :external_sku, String |
#name ⇒ String
Returns This name describes your item and will appear on the invoice when it’s purchased on a one time basis.
35 |
# File 'lib/recurly/requests/item_update.rb', line 35 define_attribute :name, String |
#revenue_schedule_type ⇒ String
Returns Revenue schedule type.
39 |
# File 'lib/recurly/requests/item_update.rb', line 39 define_attribute :revenue_schedule_type, String |
#tax_code ⇒ String
Returns Used by Avalara, Vertex, and Recurly’s EU VAT tax feature. The tax code values are specific to each tax system. If you are using Recurly’s EU VAT feature you can use unknown, physical, or digital.
43 |
# File 'lib/recurly/requests/item_update.rb', line 43 define_attribute :tax_code, String |
#tax_exempt ⇒ Boolean
Returns true exempts tax on the item, false applies tax on the item.
47 |
# File 'lib/recurly/requests/item_update.rb', line 47 define_attribute :tax_exempt, :Boolean |