Class: Recurly::Requests::LineItemRefund
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::LineItemRefund
- Defined in:
- lib/recurly/requests/line_item_refund.rb
Instance Attribute Summary collapse
-
#amount ⇒ Float
The specific amount to be refunded from the adjustment.
-
#id ⇒ String
Line item ID.
-
#percentage ⇒ Integer
The percentage of the adjustment’s remaining balance to refund.
-
#prorate ⇒ Boolean
Set to
trueif the line item should be prorated; set tofalseif not. -
#quantity ⇒ Integer
Line item quantity to be refunded.
-
#quantity_decimal ⇒ String
Decimal quantity to refund.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#amount ⇒ Float
Returns The specific amount to be refunded from the adjustment. Must be less than or equal to the adjustment’s remaining balance. If quantity, quantity_decimal and percentage are not present, amount is required. If quantity, quantity_decimal, or percentage is present, amount must be absent.
11 |
# File 'lib/recurly/requests/line_item_refund.rb', line 11 define_attribute :amount, Float |
#id ⇒ String
Returns Line item ID.
15 |
# File 'lib/recurly/requests/line_item_refund.rb', line 15 define_attribute :id, String |
#percentage ⇒ Integer
Returns The percentage of the adjustment’s remaining balance to refund. If quantity, quantity_decimal and amount_in_cents are not present, percentage is required. If quantity, quantity_decimal or amount_in_cents is present, percentage must be absent.
19 |
# File 'lib/recurly/requests/line_item_refund.rb', line 19 define_attribute :percentage, Integer |
#prorate ⇒ Boolean
Returns Set to true if the line item should be prorated; set to false if not. This can only be used on line items that have a start and end date.
23 |
# File 'lib/recurly/requests/line_item_refund.rb', line 23 define_attribute :prorate, :Boolean |
#quantity ⇒ Integer
Returns Line item quantity to be refunded. Must be less than or equal to the quantity_remaining. If quantity_decimal, amount, and percentage are not present, quantity is required. If amount or percentage is present, quantity must be absent.
27 |
# File 'lib/recurly/requests/line_item_refund.rb', line 27 define_attribute :quantity, Integer |
#quantity_decimal ⇒ String
Returns Decimal quantity to refund. The quantity_decimal will be used to refund charges that has a NOT null quantity decimal. Must be less than or equal to the quantity_decimal_remaining. If quantity, amount, and percentage are not present, quantity_decimal is required. If amount or percentage is present, quantity_decimal must be absent. The Decimal Quantity feature must be enabled to utilize this field.
31 |
# File 'lib/recurly/requests/line_item_refund.rb', line 31 define_attribute :quantity_decimal, String |