Class: Recurly::Requests::PurchaseCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::PurchaseCreate
- Defined in:
- lib/recurly/requests/purchase_create.rb
Instance Attribute Summary collapse
- #account ⇒ AccountPurchase
-
#collection_method ⇒ String
Collection method.
-
#coupon_codes ⇒ Array[String]
A list of coupon_codes to be redeemed on the subscription or account during the purchase.
-
#credit_customer_notes ⇒ String
Notes to be put on the credit invoice resulting from credits in the purchase, if any.
-
#currency ⇒ String
3-letter ISO 4217 currency code.
-
#customer_notes ⇒ String
Customer notes.
-
#gateway_code ⇒ String
The default payment gateway identifier to be used for the purchase transaction.
-
#gift_card_redemption_code ⇒ String
A gift card redemption code to be redeemed on the purchase invoice.
-
#line_items ⇒ Array[LineItemCreate]
A list of one time charges or credits to be created with the purchase.
-
#net_terms ⇒ Integer
Integer representing the number of days after an invoice’s creation that the invoice will become past due.
-
#po_number ⇒ String
For manual invoicing, this identifies the PO number associated with the subscription.
- #shipping ⇒ ShippingPurchase
-
#subscriptions ⇒ Array[SubscriptionPurchase]
A list of subscriptions to be created with the purchase.
-
#terms_and_conditions ⇒ String
Terms and conditions to be put on the purchase invoice.
-
#transaction_type ⇒ String
An optional type designation for the payment gateway transaction created by this request.
-
#vat_reverse_charge_notes ⇒ String
VAT reverse charge notes for cross border European tax settlement.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#account ⇒ AccountPurchase
11 |
# File 'lib/recurly/requests/purchase_create.rb', line 11 define_attribute :account, :AccountPurchase |
#collection_method ⇒ String
Returns Collection method.
15 |
# File 'lib/recurly/requests/purchase_create.rb', line 15 define_attribute :collection_method, String |
#coupon_codes ⇒ Array[String]
Returns A list of coupon_codes to be redeemed on the subscription or account during the purchase.
19 |
# File 'lib/recurly/requests/purchase_create.rb', line 19 define_attribute :coupon_codes, Array, { :item_type => String } |
#credit_customer_notes ⇒ String
Returns Notes to be put on the credit invoice resulting from credits in the purchase, if any.
23 |
# File 'lib/recurly/requests/purchase_create.rb', line 23 define_attribute :credit_customer_notes, String |
#currency ⇒ String
Returns 3-letter ISO 4217 currency code.
27 |
# File 'lib/recurly/requests/purchase_create.rb', line 27 define_attribute :currency, String |
#customer_notes ⇒ String
Returns Customer notes.
31 |
# File 'lib/recurly/requests/purchase_create.rb', line 31 define_attribute :customer_notes, String |
#gateway_code ⇒ String
Returns The default payment gateway identifier to be used for the purchase transaction. This will also be applied as the default for any subscriptions included in the purchase request.
35 |
# File 'lib/recurly/requests/purchase_create.rb', line 35 define_attribute :gateway_code, String |
#gift_card_redemption_code ⇒ String
Returns A gift card redemption code to be redeemed on the purchase invoice.
39 |
# File 'lib/recurly/requests/purchase_create.rb', line 39 define_attribute :gift_card_redemption_code, String |
#line_items ⇒ Array[LineItemCreate]
Returns A list of one time charges or credits to be created with the purchase.
43 |
# File 'lib/recurly/requests/purchase_create.rb', line 43 define_attribute :line_items, Array, { :item_type => :LineItemCreate } |
#net_terms ⇒ Integer
Returns Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.
47 |
# File 'lib/recurly/requests/purchase_create.rb', line 47 define_attribute :net_terms, Integer |
#po_number ⇒ String
Returns For manual invoicing, this identifies the PO number associated with the subscription.
51 |
# File 'lib/recurly/requests/purchase_create.rb', line 51 define_attribute :po_number, String |
#shipping ⇒ ShippingPurchase
55 |
# File 'lib/recurly/requests/purchase_create.rb', line 55 define_attribute :shipping, :ShippingPurchase |
#subscriptions ⇒ Array[SubscriptionPurchase]
Returns A list of subscriptions to be created with the purchase.
59 |
# File 'lib/recurly/requests/purchase_create.rb', line 59 define_attribute :subscriptions, Array, { :item_type => :SubscriptionPurchase } |
#terms_and_conditions ⇒ String
Returns Terms and conditions to be put on the purchase invoice.
63 |
# File 'lib/recurly/requests/purchase_create.rb', line 63 define_attribute :terms_and_conditions, String |
#transaction_type ⇒ String
Returns An optional type designation for the payment gateway transaction created by this request. Supports ‘moto’ value, which is the acronym for mail order and telephone transactions.
67 |
# File 'lib/recurly/requests/purchase_create.rb', line 67 define_attribute :transaction_type, String |
#vat_reverse_charge_notes ⇒ String
Returns VAT reverse charge notes for cross border European tax settlement.
71 |
# File 'lib/recurly/requests/purchase_create.rb', line 71 define_attribute :vat_reverse_charge_notes, String |