Class: Recurly::Requests::RecoveryBillingInfoCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/recovery_billing_info_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#addressRecoveryAddress

Returns:



11
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 11

define_attribute :address, :RecoveryAddress

#backup_payment_methodBoolean

Returns The ‘backup_payment_method` field is used to designate a billing info as a backup on the account that will be tried if the initial billing info used for an invoice is declined. All payment methods, including the billing info marked `primary_payment_method` can be set as a backup. An account can have a maximum of 1 backup, if a user sets a different payment method as a backup, the existing backup will no longer be marked as such.

Returns:

  • (Boolean)

    The ‘backup_payment_method` field is used to designate a billing info as a backup on the account that will be tried if the initial billing info used for an invoice is declined. All payment methods, including the billing info marked `primary_payment_method` can be set as a backup. An account can have a maximum of 1 backup, if a user sets a different payment method as a backup, the existing backup will no longer be marked as such.



15
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 15

define_attribute :backup_payment_method, :Boolean

#companyString

Returns Company name.

Returns:

  • (String)

    Company name



19
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 19

define_attribute :company, String

#first_nameString

Returns First name.

Returns:

  • (String)

    First name



23
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 23

define_attribute :first_name, String

#gateway_codeString

Returns An identifier for a specific payment gateway.

Returns:

  • (String)

    An identifier for a specific payment gateway.



27
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 27

define_attribute :gateway_code, String

#ip_addressString

Returns *STRONGLY RECOMMENDED* Customer’s IP address when updating their billing information.

Returns:

  • (String)

    *STRONGLY RECOMMENDED* Customer’s IP address when updating their billing information.



31
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 31

define_attribute :ip_address, String

#last_nameString

Returns Last name.

Returns:

  • (String)

    Last name



35
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 35

define_attribute :last_name, String

#network_transaction_idString

Returns Network transaction ID from the previous customer-in-session subscription signup or billing info storage. - 10-15 alphanumeric characters for Mastercard - 14-15 alphanumeric for Visa - 15 digits for all other brands - 16 alphanumeric characters for Cartes Bancaires, which are processed as Visa or Mastercard.

Returns:

  • (String)

    Network transaction ID from the previous customer-in-session subscription signup or billing info storage. - 10-15 alphanumeric characters for Mastercard - 14-15 alphanumeric for Visa - 15 digits for all other brands - 16 alphanumeric characters for Cartes Bancaires, which are processed as Visa or Mastercard



39
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 39

define_attribute :network_transaction_id, String

#payment_gateway_referencesArray[PaymentGatewayReferences]

Returns Array of Payment Gateway References, each a reference to a third-party gateway object of varying types.

Returns:

  • (Array[PaymentGatewayReferences])

    Array of Payment Gateway References, each a reference to a third-party gateway object of varying types.



43
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 43

define_attribute :payment_gateway_references, Array, { :item_type => :PaymentGatewayReferences }

#primary_payment_methodBoolean

Returns The ‘primary_payment_method` field is used to designate the primary billing info on the account. An account can have a maximum of 1 primary. If a user sets a different payment method as a primary, then the existing primary will no longer be marked as such.

Returns:

  • (Boolean)

    The ‘primary_payment_method` field is used to designate the primary billing info on the account. An account can have a maximum of 1 primary. If a user sets a different payment method as a primary, then the existing primary will no longer be marked as such.



47
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 47

define_attribute :primary_payment_method, :Boolean

#transactionsArray[RecoveryTransactionCreate]

Returns Transactions from previous collection attempts for this payment method.

Returns:



51
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 51

define_attribute :transactions, Array, { :item_type => :RecoveryTransactionCreate }