Class: Recurly::Requests::RecoveryInvoiceCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/recovery_invoice_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#accountRecoveryAccountCreate



11
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 11

define_attribute :account, :RecoveryAccountCreate

#currencyString

Returns 3-letter ISO 4217 currency code.

Returns:

  • (String)

    3-letter ISO 4217 currency code.



15
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 15

define_attribute :currency, String

#due_atDateTime

Returns Date invoice was originally due. Must be in the past.

Returns:

  • (DateTime)

    Date invoice was originally due. Must be in the past.



19
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 19

define_attribute :due_at, DateTime

#external_recovery_eligibleBoolean

Returns Must be set to ‘true` to acknowledge that the invoice is eligible for external recovery. Requests with `false`, omitted, or non-boolean values will be rejected.

Returns:

  • (Boolean)

    Must be set to ‘true` to acknowledge that the invoice is eligible for external recovery. Requests with `false`, omitted, or non-boolean values will be rejected.



23
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 23

define_attribute :external_recovery_eligible, :Boolean

#line_itemsArray[RecoveryLineItemCreate]

Returns Line items to include on the invoice. Currency is specified at the root level and must not be included in individual line items.

Returns:

  • (Array[RecoveryLineItemCreate])

    Line items to include on the invoice. Currency is specified at the root level and must not be included in individual line items.



27
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 27

define_attribute :line_items, Array, { :item_type => :RecoveryLineItemCreate }

#po_numberString

Returns This identifies the PO number associated with the subscription.

Returns:

  • (String)

    This identifies the PO number associated with the subscription.



31
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 31

define_attribute :po_number, String