Class: Recurly::Requests::RecoveryLineItemCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/recovery_line_item_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#custom_fieldsArray[CustomField]

Returns The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.

Returns:

  • (Array[CustomField])

    The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.



11
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 11

define_attribute :custom_fields, Array, { :item_type => :CustomField }

#descriptionString

Returns Description that appears on the invoice.

Returns:

  • (String)

    Description that appears on the invoice.



15
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 15

define_attribute :description, String

#harmonized_system_codeString

Returns The Harmonized System (HS) code is an internationally standardized system of names and numbers to classify traded products. The HS code, sometimes called Commodity Code, is used by customs authorities around the world to identify products when assessing duties and taxes. The HS code may also be referred to as the tariff code or customs code. Values should contain only digits and decimals.

Returns:

  • (String)

    The Harmonized System (HS) code is an internationally standardized system of names and numbers to classify traded products. The HS code, sometimes called Commodity Code, is used by customs authorities around the world to identify products when assessing duties and taxes. The HS code may also be referred to as the tariff code or customs code. Values should contain only digits and decimals.



19
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 19

define_attribute :harmonized_system_code, String

#product_codeString

Returns Optional field to track a product code or SKU for the line item. This can be used to later reporting on product purchases.

Returns:

  • (String)

    Optional field to track a product code or SKU for the line item. This can be used to later reporting on product purchases.



23
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 23

define_attribute :product_code, String

#quantityInteger

Returns This number will be multiplied by the unit amount to compute the subtotal before any discounts or taxes.

Returns:

  • (Integer)

    This number will be multiplied by the unit amount to compute the subtotal before any discounts or taxes.



27
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 27

define_attribute :quantity, Integer

#taxFloat

Returns The tax amount for the line item.

Returns:

  • (Float)

    The tax amount for the line item.



31
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 31

define_attribute :tax, Float

#unit_amountFloat

Returns A positive or negative amount will result in a positive ‘unit_amount`.

Returns:

  • (Float)

    A positive or negative amount will result in a positive ‘unit_amount`.



35
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 35

define_attribute :unit_amount, Float