Class: Recurly::Requests::RecoveryTransactionCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/recovery_transaction_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#attempted_collection_dateDateTime

Returns The date the original payment collection was attempted.

Returns:

  • (DateTime)

    The date the original payment collection was attempted.



11
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 11

define_attribute :attempted_collection_date, DateTime

#gateway_error_codeString

Returns The error code returned by the payment gateway for the original payment collection attempt.

Returns:

  • (String)

    The error code returned by the payment gateway for the original payment collection attempt.



15
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 15

define_attribute :gateway_error_code, String

#merchant_advice_codeString

Returns The advice code returned by the payment gateway for the original payment collection attempt. This field is only applicable for certain gateways.

Returns:

  • (String)

    The advice code returned by the payment gateway for the original payment collection attempt. This field is only applicable for certain gateways.



19
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 19

define_attribute :merchant_advice_code, String