Class: Recurly::Requests::SubscriptionUpdate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/subscription_update.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#auto_renewBoolean

Returns Whether the subscription renews at the end of its term.

Returns:

  • (Boolean)

    Whether the subscription renews at the end of its term.



11
# File 'lib/recurly/requests/subscription_update.rb', line 11

define_attribute :auto_renew, :Boolean

#billing_info_idString

Returns The billing_info_id is the value that represents a specific billing info for an end customer. When billing_info_id is used to assign billing info to the subscription, all future billing events for the subscription will bill to the specified billing info. billing_info_id can ONLY be used for sites utilizing the Wallet feature.

Returns:

  • (String)

    The billing_info_id is the value that represents a specific billing info for an end customer. When billing_info_id is used to assign billing info to the subscription, all future billing events for the subscription will bill to the specified billing info. billing_info_id can ONLY be used for sites utilizing the Wallet feature.



15
# File 'lib/recurly/requests/subscription_update.rb', line 15

define_attribute :billing_info_id, String

#collection_methodString

Returns Change collection method.

Returns:

  • (String)

    Change collection method



19
# File 'lib/recurly/requests/subscription_update.rb', line 19

define_attribute :collection_method, String

#credit_application_policyCreditApplicationPolicy

Returns Controls whether credit invoices are automatically applied to new invoices. The mode field determines the application behavior. When mode is all, the optional allowed_origins array can restrict which credit invoice origins are applied.

Returns:

  • (CreditApplicationPolicy)

    Controls whether credit invoices are automatically applied to new invoices. The mode field determines the application behavior. When mode is all, the optional allowed_origins array can restrict which credit invoice origins are applied.



23
# File 'lib/recurly/requests/subscription_update.rb', line 23

define_attribute :credit_application_policy, :CreditApplicationPolicy

#custom_fieldsArray[CustomField]

Returns The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.

Returns:

  • (Array[CustomField])

    The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.



27
# File 'lib/recurly/requests/subscription_update.rb', line 27

define_attribute :custom_fields, Array, { :item_type => :CustomField }

#customer_notesString

Returns Specify custom notes to add or override Customer Notes. Custom notes will stay with a subscription on all renewals.

Returns:

  • (String)

    Specify custom notes to add or override Customer Notes. Custom notes will stay with a subscription on all renewals.



31
# File 'lib/recurly/requests/subscription_update.rb', line 31

define_attribute :customer_notes, String

#gateway_codeString

Returns If present, this subscription’s transactions will use the payment gateway with this code.

Returns:

  • (String)

    If present, this subscription’s transactions will use the payment gateway with this code.



35
# File 'lib/recurly/requests/subscription_update.rb', line 35

define_attribute :gateway_code, String

#net_termsInteger

Returns Integer paired with ‘Net Terms Type` and representing the number of days past the current date (for net Net Terms Type) or days after the last day of the current month (for eom Net Terms Type) that the invoice will become past due. For manual collection method, an additional 24 hours is added to ensure the customer has the entire last day to make payment before becoming past due. For example: If an invoice is due `net 0`, it is due ’On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due ‘net 30`, it will become past due at 31 days exactly. If an invoice is due `eom 30`, it will become past due 31 days from the last day of the current month. For automatic collection method, the additional 24 hours is not added. For example, On-Receipt is due immediately, and `net 30` will become due exactly 30 days from invoice generation, at which point Recurly will attempt collection. When eom Net Terms Type is passed, the value for `Net Terms` is restricted to `0, 15, 30, 45, 60, or 90`. For more information on how net terms work with manual collection visit our docs page (docs.recurly.com/docs/manual-payments#section-collection-terms) or visit (docs.recurly.com/docs/automatic-invoicing-terms#section-collection-terms) for information about net terms using automatic collection.

Returns:

  • (Integer)

    Integer paired with ‘Net Terms Type` and representing the number of days past the current date (for net Net Terms Type) or days after the last day of the current month (for eom Net Terms Type) that the invoice will become past due. For manual collection method, an additional 24 hours is added to ensure the customer has the entire last day to make payment before becoming past due. For example: If an invoice is due `net 0`, it is due ’On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due ‘net 30`, it will become past due at 31 days exactly. If an invoice is due `eom 30`, it will become past due 31 days from the last day of the current month. For automatic collection method, the additional 24 hours is not added. For example, On-Receipt is due immediately, and `net 30` will become due exactly 30 days from invoice generation, at which point Recurly will attempt collection. When eom Net Terms Type is passed, the value for `Net Terms` is restricted to `0, 15, 30, 45, 60, or 90`. For more information on how net terms work with manual collection visit our docs page (docs.recurly.com/docs/manual-payments#section-collection-terms) or visit (docs.recurly.com/docs/automatic-invoicing-terms#section-collection-terms) for information about net terms using automatic collection.



39
# File 'lib/recurly/requests/subscription_update.rb', line 39

define_attribute :net_terms, Integer

#net_terms_typeString

Returns Optionally supplied string that may be either net or eom (end-of-month). When net, an invoice becomes past due the specified number of ‘Net Terms` days from the current date. When eom an invoice becomes past due the specified number of `Net Terms` days from the last day of the current month.

Returns:

  • (String)

    Optionally supplied string that may be either net or eom (end-of-month). When net, an invoice becomes past due the specified number of ‘Net Terms` days from the current date. When eom an invoice becomes past due the specified number of `Net Terms` days from the last day of the current month.



43
# File 'lib/recurly/requests/subscription_update.rb', line 43

define_attribute :net_terms_type, String

#next_bill_dateDateTime

Returns If present, this sets the date the subscription’s next billing period will start (current_period_ends_at). This can be used to align the subscription’s billing to a specific day of the month. For a subscription in a trial period, this will change when the trial expires. This parameter is useful for postponement of a subscription to change its billing date without proration.

Returns:

  • (DateTime)

    If present, this sets the date the subscription’s next billing period will start (current_period_ends_at). This can be used to align the subscription’s billing to a specific day of the month. For a subscription in a trial period, this will change when the trial expires. This parameter is useful for postponement of a subscription to change its billing date without proration.



47
# File 'lib/recurly/requests/subscription_update.rb', line 47

define_attribute :next_bill_date, DateTime

#po_numberString

Returns For manual invoicing, this identifies the PO number associated with the subscription.

Returns:

  • (String)

    For manual invoicing, this identifies the PO number associated with the subscription.



51
# File 'lib/recurly/requests/subscription_update.rb', line 51

define_attribute :po_number, String

#price_segment_idString

Returns The price segment ID, e.g. e28zov4fw0v2.

Returns:

  • (String)

    The price segment ID, e.g. e28zov4fw0v2.



55
# File 'lib/recurly/requests/subscription_update.rb', line 55

define_attribute :price_segment_id, String

#remaining_billing_cyclesInteger

Returns The remaining billing cycles in the current term.

Returns:

  • (Integer)

    The remaining billing cycles in the current term.



59
# File 'lib/recurly/requests/subscription_update.rb', line 59

define_attribute :remaining_billing_cycles, Integer

#renewal_billing_cyclesInteger

Returns If ‘auto_renew=true`, when a term completes, total_billing_cycles takes this value as the length of subsequent terms. Defaults to the plan’s total_billing_cycles.

Returns:

  • (Integer)

    If ‘auto_renew=true`, when a term completes, total_billing_cycles takes this value as the length of subsequent terms. Defaults to the plan’s total_billing_cycles.



63
# File 'lib/recurly/requests/subscription_update.rb', line 63

define_attribute :renewal_billing_cycles, Integer

#revenue_schedule_typeString

Returns Revenue schedule type.

Returns:

  • (String)

    Revenue schedule type



67
# File 'lib/recurly/requests/subscription_update.rb', line 67

define_attribute :revenue_schedule_type, String

#shippingSubscriptionShippingUpdate

Returns Subscription shipping details.

Returns:



71
# File 'lib/recurly/requests/subscription_update.rb', line 71

define_attribute :shipping, :SubscriptionShippingUpdate

#tax_inclusiveBoolean

Returns This field is deprecated. Please do not use it.

Returns:

  • (Boolean)

    This field is deprecated. Please do not use it.



75
# File 'lib/recurly/requests/subscription_update.rb', line 75

define_attribute :tax_inclusive, :Boolean

#terms_and_conditionsString

Returns Specify custom notes to add or override Terms and Conditions. Custom notes will stay with a subscription on all renewals.

Returns:

  • (String)

    Specify custom notes to add or override Terms and Conditions. Custom notes will stay with a subscription on all renewals.



79
# File 'lib/recurly/requests/subscription_update.rb', line 79

define_attribute :terms_and_conditions, String