Class: Recurly::Resources::AddOnMini

Inherits:
Recurly::Resource show all
Defined in:
lib/recurly/resources/add_on_mini.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Resource

#attributes

Method Summary

Methods inherited from Recurly::Resource

#==, #get_response, #inspect, #requires_client?, #to_json, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#accounting_codeString

Returns Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.

Returns:

  • (String)

    Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.



11
# File 'lib/recurly/resources/add_on_mini.rb', line 11

define_attribute :accounting_code, String

#codeString

Returns The unique identifier for the add-on within its plan.

Returns:

  • (String)

    The unique identifier for the add-on within its plan.



15
# File 'lib/recurly/resources/add_on_mini.rb', line 15

define_attribute :code, String

#idString

Returns Add-on ID.

Returns:

  • (String)

    Add-on ID



19
# File 'lib/recurly/resources/add_on_mini.rb', line 19

define_attribute :id, String

#nameString

Returns Describes your add-on and will appear in subscribers’ invoices.

Returns:

  • (String)

    Describes your add-on and will appear in subscribers’ invoices.



23
# File 'lib/recurly/resources/add_on_mini.rb', line 23

define_attribute :name, String

#objectString

Returns Object type.

Returns:

  • (String)

    Object type



27
# File 'lib/recurly/resources/add_on_mini.rb', line 27

define_attribute :object, String