Class: Recurly::Resources::CouponRedemptionRemainingDuration
- Inherits:
-
Recurly::Resource
- Object
- Recurly::Resource
- Recurly::Resources::CouponRedemptionRemainingDuration
- Defined in:
- lib/recurly/resources/coupon_redemption_remaining_duration.rb
Instance Attribute Summary collapse
-
#expires_at ⇒ DateTime
Present when
typeistemporal. -
#redemptions_remaining ⇒ Integer
The number of redemption periods remaining for which this coupon will still apply.
-
#type ⇒ String
The coupon's duration type.
Attributes inherited from Recurly::Resource
Method Summary
Methods inherited from Recurly::Resource
#==, #get_response, #inspect, #requires_client?, #to_json, #to_s
Methods included from Schema::SchemaFactory
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#expires_at ⇒ DateTime
Returns Present when type is temporal. The datetime after which this redemption will no longer apply.
11 |
# File 'lib/recurly/resources/coupon_redemption_remaining_duration.rb', line 11 define_attribute :expires_at, DateTime |
#redemptions_remaining ⇒ Integer
Returns The number of redemption periods remaining for which this coupon will still apply.
15 |
# File 'lib/recurly/resources/coupon_redemption_remaining_duration.rb', line 15 define_attribute :redemptions_remaining, Integer |
#type ⇒ String
Returns The coupon's duration type. temporal includes an expires_at timestamp. billing_periods includes a redemptions_remaining count of billing cycles. forever and single_use have no additional fields.
19 |
# File 'lib/recurly/resources/coupon_redemption_remaining_duration.rb', line 19 define_attribute :type, String |