Class: Recurly::Resources::CustomField

Inherits:
Recurly::Resource show all
Defined in:
lib/recurly/resources/custom_field.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Resource

#attributes

Method Summary

Methods inherited from Recurly::Resource

#==, #get_response, #inspect, #requires_client?, #to_json, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#nameString

Returns Fields must be created in the UI before values can be assigned to them.

Returns:

  • (String)

    Fields must be created in the UI before values can be assigned to them.



11
# File 'lib/recurly/resources/custom_field.rb', line 11

define_attribute :name, String

#source_record_idString

Returns The UUID of the record this custom field was automatically copied from. Only present when the field was copied from another record.

Returns:

  • (String)

    The UUID of the record this custom field was automatically copied from. Only present when the field was copied from another record.



15
# File 'lib/recurly/resources/custom_field.rb', line 15

define_attribute :source_record_id, String

#source_record_typeString

Returns The type of record this custom field was automatically copied from. Only present when the field was copied from another record.

Returns:

  • (String)

    The type of record this custom field was automatically copied from. Only present when the field was copied from another record.



19
# File 'lib/recurly/resources/custom_field.rb', line 19

define_attribute :source_record_type, String

#valueString

Returns Any values that resemble a credit card number or security code (CVV/CVC) will be rejected.

Returns:

  • (String)

    Any values that resemble a credit card number or security code (CVV/CVC) will be rejected.



23
# File 'lib/recurly/resources/custom_field.rb', line 23

define_attribute :value, String