Class: Recurly::Resources::UniqueCouponCodeGenerationResponse

Inherits:
Recurly::Resource show all
Defined in:
lib/recurly/resources/unique_coupon_code_generation_response.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Resource

#attributes

Method Summary

Methods inherited from Recurly::Resource

#==, #get_response, #inspect, #requires_client?, #to_json, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#objectString

Returns Object type.

Returns:

  • (String)

    Object type



11
# File 'lib/recurly/resources/unique_coupon_code_generation_response.rb', line 11

define_attribute :object, String

#unique_coupon_codesArray[UniqueCouponCode]

Returns An array containing the newly generated unique coupon codes.

Returns:

  • (Array[UniqueCouponCode])

    An array containing the newly generated unique coupon codes.



15
# File 'lib/recurly/resources/unique_coupon_code_generation_response.rb', line 15

define_attribute :unique_coupon_codes, Array, { :item_type => :UniqueCouponCode }