Method: Recurly::Client#list_transactions
- Defined in:
- lib/recurly/client/operations.rb
#list_transactions(**options) ⇒ Pager<Resources::Transaction>
List a site’s transactions
list_transactions api documentation
commas as separators, e.g. +ids=h1at4d57xlmy,gyqgg0d3v9n1,jrsm5b4yefg6+.
*Important notes:*
* The +ids+ parameter cannot be used with any other ordering or filtering
parameters (+limit+, +order+, +sort+, +begin_time+, +end_time+, etc)
* Invalid or unknown IDs will be ignored, so you should check that the
results correspond to your request.
* Records are returned in an arbitrary order. Since results are all
returned at once you can sort the records yourself.
:limit [Integer] Limit number of records 1-200.
:order [String] Sort order.
:sort [String] Sort field. You *really* only want to sort by +updated_at+ in ascending
order. In descending order updated records will move behind the cursor and could
prevent some records from being returned.
:begin_time [DateTime] Inclusively filter by begin_time when +sort=created_at+ or +sort=updated_at+.
*Note:* this value is an ISO8601 timestamp. A partial timestamp that does not include a time zone will default to UTC.
:end_time [DateTime] Inclusively filter by end_time when +sort=created_at+ or +sort=updated_at+.
*Note:* this value is an ISO8601 timestamp. A partial timestamp that does not include a time zone will default to UTC.
:type [String] Filter by type field. The value +payment+ will return both +purchase+ and +capture+ transactions.
:success [String] Filter by success field.
4398 4399 4400 4401 |
# File 'lib/recurly/client/operations.rb', line 4398 def list_transactions(**) path = "/transactions" pager(path, **) end |