Class: Recurly::Requests::AddOnUpdate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::AddOnUpdate
- Defined in:
- lib/recurly/requests/add_on_update.rb
Instance Attribute Summary collapse
-
#accounting_code ⇒ String
Accounting code for invoice line items for this add-on.
-
#code ⇒ String
The unique identifier for the add-on within its plan.
-
#currencies ⇒ Array[AddOnPricing]
Add-on pricing.
-
#default_quantity ⇒ Integer
Default quantity for the hosted pages.
-
#display_quantity ⇒ Boolean
Determines if the quantity field is displayed on the hosted pages for the add-on.
-
#id ⇒ String
Add-on ID.
-
#name ⇒ String
Describes your add-on and will appear in subscribers’ invoices.
-
#tax_code ⇒ String
Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#accounting_code ⇒ String
Returns Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.
11 |
# File 'lib/recurly/requests/add_on_update.rb', line 11 define_attribute :accounting_code, String |
#code ⇒ String
Returns The unique identifier for the add-on within its plan.
15 |
# File 'lib/recurly/requests/add_on_update.rb', line 15 define_attribute :code, String |
#currencies ⇒ Array[AddOnPricing]
Returns Add-on pricing.
19 |
# File 'lib/recurly/requests/add_on_update.rb', line 19 define_attribute :currencies, Array, { :item_type => :AddOnPricing } |
#default_quantity ⇒ Integer
Returns Default quantity for the hosted pages.
23 |
# File 'lib/recurly/requests/add_on_update.rb', line 23 define_attribute :default_quantity, Integer |
#display_quantity ⇒ Boolean
Returns Determines if the quantity field is displayed on the hosted pages for the add-on.
27 |
# File 'lib/recurly/requests/add_on_update.rb', line 27 define_attribute :display_quantity, :Boolean |
#id ⇒ String
Returns Add-on ID.
31 |
# File 'lib/recurly/requests/add_on_update.rb', line 31 define_attribute :id, String |
#name ⇒ String
Returns Describes your add-on and will appear in subscribers’ invoices.
35 |
# File 'lib/recurly/requests/add_on_update.rb', line 35 define_attribute :name, String |
#tax_code ⇒ String
Returns Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules. If you have your own AvaTax or Vertex account configured, use their tax codes to assign specific tax rules. If you are using Recurly’s EU VAT feature, you can use values of unknown, physical, or digital.
39 |
# File 'lib/recurly/requests/add_on_update.rb', line 39 define_attribute :tax_code, String |