Class: Recurly::Requests::InvoiceCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::InvoiceCreate
- Defined in:
- lib/recurly/requests/invoice_create.rb
Instance Attribute Summary collapse
-
#charge_customer_notes ⇒ String
This will default to the Customer Notes text specified on the Invoice Settings for charge invoices.
-
#collection_method ⇒ String
An automatic invoice means a corresponding transaction is run using the account’s billing information at the same time the invoice is created.
-
#credit_customer_notes ⇒ String
This will default to the Customer Notes text specified on the Invoice Settings for credit invoices.
-
#currency ⇒ String
3-letter ISO 4217 currency code.
-
#net_terms ⇒ Integer
Integer representing the number of days after an invoice’s creation that the invoice will become past due.
-
#po_number ⇒ String
For manual invoicing, this identifies the PO number associated with the subscription.
-
#terms_and_conditions ⇒ String
This will default to the Terms and Conditions text specified on the Invoice Settings page in your Recurly admin.
-
#vat_reverse_charge_notes ⇒ String
VAT Reverse Charge Notes only appear if you have EU VAT enabled or are using your own Avalara AvaTax account and the customer is in the EU, has a VAT number, and is in a different country than your own.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#charge_customer_notes ⇒ String
Returns This will default to the Customer Notes text specified on the Invoice Settings for charge invoices. Specify custom notes to add or override Customer Notes on charge invoices.
11 |
# File 'lib/recurly/requests/invoice_create.rb', line 11 define_attribute :charge_customer_notes, String |
#collection_method ⇒ String
Returns An automatic invoice means a corresponding transaction is run using the account’s billing information at the same time the invoice is created. Manual invoices are created without a corresponding transaction. The merchant must enter a manual payment transaction or have the customer pay the invoice with an automatic method, like credit card, PayPal, Amazon, or ACH bank payment.
15 |
# File 'lib/recurly/requests/invoice_create.rb', line 15 define_attribute :collection_method, String |
#credit_customer_notes ⇒ String
Returns This will default to the Customer Notes text specified on the Invoice Settings for credit invoices. Specify customer notes to add or override Customer Notes on credit invoices.
19 |
# File 'lib/recurly/requests/invoice_create.rb', line 19 define_attribute :credit_customer_notes, String |
#currency ⇒ String
Returns 3-letter ISO 4217 currency code.
23 |
# File 'lib/recurly/requests/invoice_create.rb', line 23 define_attribute :currency, String |
#net_terms ⇒ Integer
Returns Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.
27 |
# File 'lib/recurly/requests/invoice_create.rb', line 27 define_attribute :net_terms, Integer |
#po_number ⇒ String
Returns For manual invoicing, this identifies the PO number associated with the subscription.
31 |
# File 'lib/recurly/requests/invoice_create.rb', line 31 define_attribute :po_number, String |
#terms_and_conditions ⇒ String
Returns This will default to the Terms and Conditions text specified on the Invoice Settings page in your Recurly admin. Specify custom notes to add or override Terms and Conditions.
35 |
# File 'lib/recurly/requests/invoice_create.rb', line 35 define_attribute :terms_and_conditions, String |
#vat_reverse_charge_notes ⇒ String
Returns VAT Reverse Charge Notes only appear if you have EU VAT enabled or are using your own Avalara AvaTax account and the customer is in the EU, has a VAT number, and is in a different country than your own. This will default to the VAT Reverse Charge Notes text specified on the Tax Settings page in your Recurly admin, unless custom notes were created with the original subscription.
39 |
# File 'lib/recurly/requests/invoice_create.rb', line 39 define_attribute :vat_reverse_charge_notes, String |