Method: Recurly::Requests::LineItemCreate#tax_code
- Defined in:
- lib/recurly/requests/line_item_create.rb
#tax_code ⇒ String
Returns Optional field used by Avalara, Vertex, and Recurly’s In-the-Box tax solution to determine taxation rules. You can pass in specific tax codes using any of these tax integrations. For Recurly’s In-the-Box tax offering you can also choose to instead use simple values of unknown, physical, or digital tax codes.
95 |
# File 'lib/recurly/requests/line_item_create.rb', line 95 define_attribute :tax_code, String |