Class: Recurly::Requests::PlanUpdate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::PlanUpdate
- Defined in:
- lib/recurly/requests/plan_update.rb
Instance Attribute Summary collapse
-
#accounting_code ⇒ String
Accounting code for invoice line items for the plan.
-
#add_ons ⇒ Array[AddOnCreate]
Add Ons.
-
#auto_renew ⇒ Boolean
Subscriptions will automatically inherit this value once they are active.
-
#code ⇒ String
Unique code to identify the plan.
-
#currencies ⇒ Array[PlanPricing]
Pricing.
-
#description ⇒ String
Optional description, not displayed.
-
#hosted_pages ⇒ PlanHostedPages
Hosted pages settings.
-
#id ⇒ String
Plan ID.
-
#name ⇒ String
This name describes your plan and will appear on the Hosted Payment Page and the subscriber’s invoice.
-
#setup_fee_accounting_code ⇒ String
Accounting code for invoice line items for the plan’s setup fee.
-
#tax_code ⇒ String
Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules.
-
#tax_exempt ⇒ Boolean
trueexempts tax on the plan,falseapplies tax on the plan. -
#total_billing_cycles ⇒ Integer
Automatically terminate plans after a defined number of billing cycles.
-
#trial_length ⇒ Integer
Length of plan’s trial period in
trial_units. -
#trial_unit ⇒ String
Units for the plan’s trial period.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#accounting_code ⇒ String
Returns Accounting code for invoice line items for the plan. If no value is provided, it defaults to plan’s code.
11 |
# File 'lib/recurly/requests/plan_update.rb', line 11 define_attribute :accounting_code, String |
#add_ons ⇒ Array[AddOnCreate]
Returns Add Ons.
15 |
# File 'lib/recurly/requests/plan_update.rb', line 15 define_attribute :add_ons, Array, { :item_type => :AddOnCreate } |
#auto_renew ⇒ Boolean
Returns Subscriptions will automatically inherit this value once they are active. If auto_renew is true, then a subscription will automatically renew its term at renewal. If auto_renew is false, then a subscription will expire at the end of its term. auto_renew can be overridden on the subscription record itself.
19 |
# File 'lib/recurly/requests/plan_update.rb', line 19 define_attribute :auto_renew, :Boolean |
#code ⇒ String
Returns Unique code to identify the plan. This is used in Hosted Payment Page URLs and in the invoice exports.
23 |
# File 'lib/recurly/requests/plan_update.rb', line 23 define_attribute :code, String |
#currencies ⇒ Array[PlanPricing]
Returns Pricing.
27 |
# File 'lib/recurly/requests/plan_update.rb', line 27 define_attribute :currencies, Array, { :item_type => :PlanPricing } |
#description ⇒ String
Returns Optional description, not displayed.
31 |
# File 'lib/recurly/requests/plan_update.rb', line 31 define_attribute :description, String |
#hosted_pages ⇒ PlanHostedPages
Returns Hosted pages settings.
35 |
# File 'lib/recurly/requests/plan_update.rb', line 35 define_attribute :hosted_pages, :PlanHostedPages |
#id ⇒ String
Returns Plan ID.
39 |
# File 'lib/recurly/requests/plan_update.rb', line 39 define_attribute :id, String |
#name ⇒ String
Returns This name describes your plan and will appear on the Hosted Payment Page and the subscriber’s invoice.
43 |
# File 'lib/recurly/requests/plan_update.rb', line 43 define_attribute :name, String |
#setup_fee_accounting_code ⇒ String
Returns Accounting code for invoice line items for the plan’s setup fee. If no value is provided, it defaults to plan’s accounting code.
47 |
# File 'lib/recurly/requests/plan_update.rb', line 47 define_attribute :setup_fee_accounting_code, String |
#tax_code ⇒ String
Returns Optional field used by Avalara, Vertex, and Recurly’s EU VAT tax feature to determine taxation rules. If you have your own AvaTax or Vertex account configured, use their tax codes to assign specific tax rules. If you are using Recurly’s EU VAT feature, you can use values of unknown, physical, or digital.
51 |
# File 'lib/recurly/requests/plan_update.rb', line 51 define_attribute :tax_code, String |
#tax_exempt ⇒ Boolean
Returns true exempts tax on the plan, false applies tax on the plan.
55 |
# File 'lib/recurly/requests/plan_update.rb', line 55 define_attribute :tax_exempt, :Boolean |
#total_billing_cycles ⇒ Integer
Returns Automatically terminate plans after a defined number of billing cycles.
59 |
# File 'lib/recurly/requests/plan_update.rb', line 59 define_attribute :total_billing_cycles, Integer |
#trial_length ⇒ Integer
Returns Length of plan’s trial period in trial_units. 0 means ‘no trial`.
63 |
# File 'lib/recurly/requests/plan_update.rb', line 63 define_attribute :trial_length, Integer |
#trial_unit ⇒ String
Returns Units for the plan’s trial period.
67 |
# File 'lib/recurly/requests/plan_update.rb', line 67 define_attribute :trial_unit, String |