Class: Recurly::Requests::RecoveryAccountCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::RecoveryAccountCreate
- Defined in:
- lib/recurly/requests/recovery_account_create.rb
Instance Attribute Summary collapse
- #address ⇒ RecoveryAddress
-
#billing_infos ⇒ Array[RecoveryBillingInfoCreate]
If the premium Wallet feature is enabled, more than one payment method can be associated with an account, and one can be designated as a primary and one as a backup.
-
#code ⇒ String
The unique identifier of the account.
-
#custom_fields ⇒ Array[CustomField]
The custom fields will only be altered when they are included in a request.
-
#dunning_campaign_id ⇒ String
Unique ID to identify a dunning campaign.
-
#email ⇒ String
The email address used for communicating with this customer.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#address ⇒ RecoveryAddress
11 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 11 define_attribute :address, :RecoveryAddress |
#billing_infos ⇒ Array[RecoveryBillingInfoCreate]
Returns If the premium Wallet feature is enabled, more than one payment method can be associated with an account, and one can be designated as a primary and one as a backup. Without the Wallet feature, only one payment method will be accepted.
15 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 15 define_attribute :billing_infos, Array, { :item_type => :RecoveryBillingInfoCreate } |
#code ⇒ String
Returns The unique identifier of the account. This cannot be changed once the account is created.
19 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 19 define_attribute :code, String |
#custom_fields ⇒ Array[CustomField]
Returns The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.
23 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 23 define_attribute :custom_fields, Array, { :item_type => :CustomField } |
#dunning_campaign_id ⇒ String
Returns Unique ID to identify a dunning campaign. Used to specify if a non-default dunning campaign should be assigned to this account. For sites without multiple dunning campaigns enabled, the default dunning campaign will always be used.
27 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 27 define_attribute :dunning_campaign_id, String |
#email ⇒ String
Returns The email address used for communicating with this customer.
31 |
# File 'lib/recurly/requests/recovery_account_create.rb', line 31 define_attribute :email, String |