Class: Recurly::Requests::RecoveryBillingInfoCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::RecoveryBillingInfoCreate
- Defined in:
- lib/recurly/requests/recovery_billing_info_create.rb
Instance Attribute Summary collapse
- #address ⇒ RecoveryAddress
-
#backup_payment_method ⇒ Boolean
The ‘backup_payment_method` field is used to designate a billing info as a backup on the account that will be tried if the initial billing info used for an invoice is declined.
-
#company ⇒ String
Company name.
-
#first_name ⇒ String
First name.
-
#gateway_code ⇒ String
An identifier for a specific payment gateway.
-
#ip_address ⇒ String
*STRONGLY RECOMMENDED* Customer’s IP address when updating their billing information.
-
#last_name ⇒ String
Last name.
-
#network_transaction_id ⇒ String
Network transaction ID from the previous customer-in-session subscription signup or billing info storage.
-
#payment_gateway_references ⇒ Array[PaymentGatewayReferences]
Array of Payment Gateway References, each a reference to a third-party gateway object of varying types.
-
#primary_payment_method ⇒ Boolean
The ‘primary_payment_method` field is used to designate the primary billing info on the account.
-
#transactions ⇒ Array[RecoveryTransactionCreate]
Transactions from previous collection attempts for this payment method.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#address ⇒ RecoveryAddress
11 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 11 define_attribute :address, :RecoveryAddress |
#backup_payment_method ⇒ Boolean
Returns The ‘backup_payment_method` field is used to designate a billing info as a backup on the account that will be tried if the initial billing info used for an invoice is declined. All payment methods, including the billing info marked `primary_payment_method` can be set as a backup. An account can have a maximum of 1 backup, if a user sets a different payment method as a backup, the existing backup will no longer be marked as such.
15 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 15 define_attribute :backup_payment_method, :Boolean |
#company ⇒ String
Returns Company name.
19 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 19 define_attribute :company, String |
#first_name ⇒ String
Returns First name.
23 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 23 define_attribute :first_name, String |
#gateway_code ⇒ String
Returns An identifier for a specific payment gateway.
27 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 27 define_attribute :gateway_code, String |
#ip_address ⇒ String
Returns *STRONGLY RECOMMENDED* Customer’s IP address when updating their billing information.
31 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 31 define_attribute :ip_address, String |
#last_name ⇒ String
Returns Last name.
35 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 35 define_attribute :last_name, String |
#network_transaction_id ⇒ String
Returns Network transaction ID from the previous customer-in-session subscription signup or billing info storage. - 10-15 alphanumeric characters for Mastercard - 14-15 alphanumeric for Visa - 15 digits for all other brands - 16 alphanumeric characters for Cartes Bancaires, which are processed as Visa or Mastercard.
39 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 39 define_attribute :network_transaction_id, String |
#payment_gateway_references ⇒ Array[PaymentGatewayReferences]
Returns Array of Payment Gateway References, each a reference to a third-party gateway object of varying types.
43 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 43 define_attribute :payment_gateway_references, Array, { :item_type => :PaymentGatewayReferences } |
#primary_payment_method ⇒ Boolean
Returns The ‘primary_payment_method` field is used to designate the primary billing info on the account. An account can have a maximum of 1 primary. If a user sets a different payment method as a primary, then the existing primary will no longer be marked as such.
47 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 47 define_attribute :primary_payment_method, :Boolean |
#transactions ⇒ Array[RecoveryTransactionCreate]
Returns Transactions from previous collection attempts for this payment method.
51 |
# File 'lib/recurly/requests/recovery_billing_info_create.rb', line 51 define_attribute :transactions, Array, { :item_type => :RecoveryTransactionCreate } |