Class: Recurly::Requests::RecoveryInvoiceCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::RecoveryInvoiceCreate
- Defined in:
- lib/recurly/requests/recovery_invoice_create.rb
Instance Attribute Summary collapse
- #account ⇒ RecoveryAccountCreate
-
#currency ⇒ String
3-letter ISO 4217 currency code.
-
#due_at ⇒ DateTime
Date invoice was originally due.
-
#external_recovery_eligible ⇒ Boolean
Must be set to ‘true` to acknowledge that the invoice is eligible for external recovery.
-
#line_items ⇒ Array[RecoveryLineItemCreate]
Line items to include on the invoice.
-
#po_number ⇒ String
This identifies the PO number associated with the subscription.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#account ⇒ RecoveryAccountCreate
11 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 11 define_attribute :account, :RecoveryAccountCreate |
#currency ⇒ String
Returns 3-letter ISO 4217 currency code.
15 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 15 define_attribute :currency, String |
#due_at ⇒ DateTime
Returns Date invoice was originally due. Must be in the past.
19 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 19 define_attribute :due_at, DateTime |
#external_recovery_eligible ⇒ Boolean
Returns Must be set to ‘true` to acknowledge that the invoice is eligible for external recovery. Requests with `false`, omitted, or non-boolean values will be rejected.
23 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 23 define_attribute :external_recovery_eligible, :Boolean |
#line_items ⇒ Array[RecoveryLineItemCreate]
Returns Line items to include on the invoice. Currency is specified at the root level and must not be included in individual line items.
27 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 27 define_attribute :line_items, Array, { :item_type => :RecoveryLineItemCreate } |
#po_number ⇒ String
Returns This identifies the PO number associated with the subscription.
31 |
# File 'lib/recurly/requests/recovery_invoice_create.rb', line 31 define_attribute :po_number, String |