Class: Recurly::Requests::RecoveryLineItemCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::RecoveryLineItemCreate
- Defined in:
- lib/recurly/requests/recovery_line_item_create.rb
Instance Attribute Summary collapse
-
#custom_fields ⇒ Array[CustomField]
The custom fields will only be altered when they are included in a request.
-
#description ⇒ String
Description that appears on the invoice.
-
#harmonized_system_code ⇒ String
The Harmonized System (HS) code is an internationally standardized system of names and numbers to classify traded products.
-
#product_code ⇒ String
Optional field to track a product code or SKU for the line item.
-
#quantity ⇒ Integer
This number will be multiplied by the unit amount to compute the subtotal before any discounts or taxes.
-
#tax ⇒ Float
The tax amount for the line item.
-
#unit_amount ⇒ Float
A positive or negative amount will result in a positive ‘unit_amount`.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#custom_fields ⇒ Array[CustomField]
Returns The custom fields will only be altered when they are included in a request. Sending an empty array will not remove any existing values. To remove a field send the name with a null or empty value.
11 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 11 define_attribute :custom_fields, Array, { :item_type => :CustomField } |
#description ⇒ String
Returns Description that appears on the invoice.
15 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 15 define_attribute :description, String |
#harmonized_system_code ⇒ String
Returns The Harmonized System (HS) code is an internationally standardized system of names and numbers to classify traded products. The HS code, sometimes called Commodity Code, is used by customs authorities around the world to identify products when assessing duties and taxes. The HS code may also be referred to as the tariff code or customs code. Values should contain only digits and decimals.
19 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 19 define_attribute :harmonized_system_code, String |
#product_code ⇒ String
Returns Optional field to track a product code or SKU for the line item. This can be used to later reporting on product purchases.
23 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 23 define_attribute :product_code, String |
#quantity ⇒ Integer
Returns This number will be multiplied by the unit amount to compute the subtotal before any discounts or taxes.
27 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 27 define_attribute :quantity, Integer |
#tax ⇒ Float
Returns The tax amount for the line item.
31 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 31 define_attribute :tax, Float |
#unit_amount ⇒ Float
Returns A positive or negative amount will result in a positive ‘unit_amount`.
35 |
# File 'lib/recurly/requests/recovery_line_item_create.rb', line 35 define_attribute :unit_amount, Float |