Class: Recurly::Requests::RecoveryTransactionCreate
- Inherits:
-
Recurly::Request
- Object
- Recurly::Request
- Recurly::Requests::RecoveryTransactionCreate
- Defined in:
- lib/recurly/requests/recovery_transaction_create.rb
Instance Attribute Summary collapse
-
#attempted_collection_date ⇒ DateTime
The date the original payment collection was attempted.
-
#gateway_error_code ⇒ String
The error code returned by the payment gateway for the original payment collection attempt.
-
#merchant_advice_code ⇒ String
The advice code returned by the payment gateway for the original payment collection attempt.
Attributes inherited from Recurly::Request
Method Summary
Methods inherited from Recurly::Request
Methods included from Schema::SchemaFactory
Methods included from Schema::RequestCaster
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#attempted_collection_date ⇒ DateTime
Returns The date the original payment collection was attempted.
11 |
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 11 define_attribute :attempted_collection_date, DateTime |
#gateway_error_code ⇒ String
Returns The error code returned by the payment gateway for the original payment collection attempt.
15 |
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 15 define_attribute :gateway_error_code, String |
#merchant_advice_code ⇒ String
Returns The advice code returned by the payment gateway for the original payment collection attempt. This field is only applicable for certain gateways.
19 |
# File 'lib/recurly/requests/recovery_transaction_create.rb', line 19 define_attribute :merchant_advice_code, String |