Class: Recurly::Requests::SubscriptionChangeCreate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/subscription_change_create.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#add_onsArray[SubscriptionAddOnUpdate]

Returns If you provide a value for this field it will replace any existing add-ons. So, when adding or modifying an add-on, you need to include the existing subscription add-ons. Unchanged add-ons can be included just using the subscription add-on’s ID: ‘“abc123”`.

Returns:

  • (Array[SubscriptionAddOnUpdate])

    If you provide a value for this field it will replace any existing add-ons. So, when adding or modifying an add-on, you need to include the existing subscription add-ons. Unchanged add-ons can be included just using the subscription add-on’s ID: ‘“abc123”`.



11
# File 'lib/recurly/requests/subscription_change_create.rb', line 11

define_attribute :add_ons, Array, { :item_type => :SubscriptionAddOnUpdate }

#collection_methodString

Returns Collection method.

Returns:

  • (String)

    Collection method



15
# File 'lib/recurly/requests/subscription_change_create.rb', line 15

define_attribute :collection_method, String

#coupon_codesArray[String]

Returns A list of coupon_codes to be redeemed on the subscription during the change. Only allowed if timeframe is now and you change something about the subscription that creates an invoice.

Returns:

  • (Array[String])

    A list of coupon_codes to be redeemed on the subscription during the change. Only allowed if timeframe is now and you change something about the subscription that creates an invoice.



19
# File 'lib/recurly/requests/subscription_change_create.rb', line 19

define_attribute :coupon_codes, Array, { :item_type => String }

#net_termsInteger

Returns Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.

Returns:

  • (Integer)

    Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.



23
# File 'lib/recurly/requests/subscription_change_create.rb', line 23

define_attribute :net_terms, Integer

#plan_codeString

Returns If you want to change to a new plan, you can provide the plan’s code or id. If both are provided the plan_id will be used.

Returns:

  • (String)

    If you want to change to a new plan, you can provide the plan’s code or id. If both are provided the plan_id will be used.



27
# File 'lib/recurly/requests/subscription_change_create.rb', line 27

define_attribute :plan_code, String

#plan_idString

Returns If you want to change to a new plan, you can provide the plan’s code or id. If both are provided the plan_id will be used.

Returns:

  • (String)

    If you want to change to a new plan, you can provide the plan’s code or id. If both are provided the plan_id will be used.



31
# File 'lib/recurly/requests/subscription_change_create.rb', line 31

define_attribute :plan_id, String

#po_numberString

Returns For manual invoicing, this identifies the PO number associated with the subscription.

Returns:

  • (String)

    For manual invoicing, this identifies the PO number associated with the subscription.



35
# File 'lib/recurly/requests/subscription_change_create.rb', line 35

define_attribute :po_number, String

#quantityInteger

Returns Optionally override the default quantity of 1.

Returns:

  • (Integer)

    Optionally override the default quantity of 1.



39
# File 'lib/recurly/requests/subscription_change_create.rb', line 39

define_attribute :quantity, Integer

#shippingSubscriptionChangeShippingCreate



43
# File 'lib/recurly/requests/subscription_change_create.rb', line 43

define_attribute :shipping, :SubscriptionChangeShippingCreate

#timeframeString

Returns The timeframe parameter controls when the upgrade or downgrade takes place. The subscription change can occur now, when the subscription is next billed, or when the subscription term ends. Generally, if you’re performing an upgrade, you will want the change to occur immediately (now). If you’re performing a downgrade, you should set the timeframe to term_end or bill_date so the change takes effect at a scheduled billing date. The renewal timeframe option is accepted as an alias for term_end.

Returns:

  • (String)

    The timeframe parameter controls when the upgrade or downgrade takes place. The subscription change can occur now, when the subscription is next billed, or when the subscription term ends. Generally, if you’re performing an upgrade, you will want the change to occur immediately (now). If you’re performing a downgrade, you should set the timeframe to term_end or bill_date so the change takes effect at a scheduled billing date. The renewal timeframe option is accepted as an alias for term_end.



47
# File 'lib/recurly/requests/subscription_change_create.rb', line 47

define_attribute :timeframe, String

#transaction_typeString

Returns An optional type designation for the payment gateway transaction created by this request. Supports ‘moto’ value, which is the acronym for mail order and telephone transactions.

Returns:

  • (String)

    An optional type designation for the payment gateway transaction created by this request. Supports ‘moto’ value, which is the acronym for mail order and telephone transactions.



51
# File 'lib/recurly/requests/subscription_change_create.rb', line 51

define_attribute :transaction_type, String

#unit_amountFloat

Returns Optionally, sets custom pricing for the subscription, overriding the plan’s default unit amount. The subscription’s current currency will be used.

Returns:

  • (Float)

    Optionally, sets custom pricing for the subscription, overriding the plan’s default unit amount. The subscription’s current currency will be used.



55
# File 'lib/recurly/requests/subscription_change_create.rb', line 55

define_attribute :unit_amount, Float