Class: Recurly::Requests::SubscriptionUpdate

Inherits:
Recurly::Request show all
Defined in:
lib/recurly/requests/subscription_update.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Request

#attributes

Method Summary

Methods inherited from Recurly::Request

#==, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::RequestCaster

#cast_request

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#auto_renewBoolean

Returns Whether the subscription renews at the end of its term.

Returns:

  • (Boolean)

    Whether the subscription renews at the end of its term.



11
# File 'lib/recurly/requests/subscription_update.rb', line 11

define_attribute :auto_renew, :Boolean

#collection_methodString

Returns Change collection method.

Returns:

  • (String)

    Change collection method



15
# File 'lib/recurly/requests/subscription_update.rb', line 15

define_attribute :collection_method, String

#custom_fieldsArray[CustomField]

Returns:



19
# File 'lib/recurly/requests/subscription_update.rb', line 19

define_attribute :custom_fields, Array, { :item_type => :CustomField }

#customer_notesString

Returns Specify custom notes to add or override Customer Notes. Custom notes will stay with a subscription on all renewals.

Returns:

  • (String)

    Specify custom notes to add or override Customer Notes. Custom notes will stay with a subscription on all renewals.



23
# File 'lib/recurly/requests/subscription_update.rb', line 23

define_attribute :customer_notes, String

#net_termsInteger

Returns Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.

Returns:

  • (Integer)

    Integer representing the number of days after an invoice’s creation that the invoice will become past due. If an invoice’s net terms are set to ‘0’, it is due ‘On Receipt’ and will become past due 24 hours after it’s created. If an invoice is due net 30, it will become past due at 31 days exactly.



27
# File 'lib/recurly/requests/subscription_update.rb', line 27

define_attribute :net_terms, Integer

#next_bill_dateDateTime

Returns If present, this sets the date the subscription’s next billing period will start (current_period_ends_at). This can be used to align the subscription’s billing to a specific day of the month. For a subscription in a trial period, this will change when the trial expires. This parameter is useful for postponement of a subscription to change its billing date without proration.

Returns:

  • (DateTime)

    If present, this sets the date the subscription’s next billing period will start (current_period_ends_at). This can be used to align the subscription’s billing to a specific day of the month. For a subscription in a trial period, this will change when the trial expires. This parameter is useful for postponement of a subscription to change its billing date without proration.



31
# File 'lib/recurly/requests/subscription_update.rb', line 31

define_attribute :next_bill_date, DateTime

#po_numberString

Returns For manual invoicing, this identifies the PO number associated with the subscription.

Returns:

  • (String)

    For manual invoicing, this identifies the PO number associated with the subscription.



35
# File 'lib/recurly/requests/subscription_update.rb', line 35

define_attribute :po_number, String

#remaining_billing_cyclesInteger

Returns The remaining billing cycles in the current term.

Returns:

  • (Integer)

    The remaining billing cycles in the current term.



39
# File 'lib/recurly/requests/subscription_update.rb', line 39

define_attribute :remaining_billing_cycles, Integer

#renewal_billing_cyclesInteger

Returns If ‘auto_renew=true`, when a term completes, total_billing_cycles takes this value as the length of subsequent terms. Defaults to the plan’s total_billing_cycles.

Returns:

  • (Integer)

    If ‘auto_renew=true`, when a term completes, total_billing_cycles takes this value as the length of subsequent terms. Defaults to the plan’s total_billing_cycles.



43
# File 'lib/recurly/requests/subscription_update.rb', line 43

define_attribute :renewal_billing_cycles, Integer

#shippingSubscriptionShippingUpdate



47
# File 'lib/recurly/requests/subscription_update.rb', line 47

define_attribute :shipping, :SubscriptionShippingUpdate

#terms_and_conditionsString

Returns Specify custom notes to add or override Terms and Conditions. Custom notes will stay with a subscription on all renewals.

Returns:

  • (String)

    Specify custom notes to add or override Terms and Conditions. Custom notes will stay with a subscription on all renewals.



51
# File 'lib/recurly/requests/subscription_update.rb', line 51

define_attribute :terms_and_conditions, String