Class: Recurly::Resources::AddOnMini
- Inherits:
-
Recurly::Resource
- Object
- Recurly::Resource
- Recurly::Resources::AddOnMini
- Defined in:
- lib/recurly/resources/add_on_mini.rb
Instance Attribute Summary collapse
-
#accounting_code ⇒ String
Accounting code for invoice line items for this add-on.
-
#code ⇒ String
The unique identifier for the add-on within its plan.
-
#id ⇒ String
Add-on ID.
-
#name ⇒ String
Describes your add-on and will appear in subscribers’ invoices.
-
#object ⇒ String
Object type.
Attributes inherited from Recurly::Resource
Method Summary
Methods inherited from Recurly::Resource
#==, #get_response, #inspect, #requires_client?, #to_json, #to_s
Methods included from Schema::SchemaFactory
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#accounting_code ⇒ String
Returns Accounting code for invoice line items for this add-on. If no value is provided, it defaults to add-on’s code.
11 |
# File 'lib/recurly/resources/add_on_mini.rb', line 11 define_attribute :accounting_code, String |
#code ⇒ String
Returns The unique identifier for the add-on within its plan.
15 |
# File 'lib/recurly/resources/add_on_mini.rb', line 15 define_attribute :code, String |
#id ⇒ String
Returns Add-on ID.
19 |
# File 'lib/recurly/resources/add_on_mini.rb', line 19 define_attribute :id, String |
#name ⇒ String
Returns Describes your add-on and will appear in subscribers’ invoices.
23 |
# File 'lib/recurly/resources/add_on_mini.rb', line 23 define_attribute :name, String |
#object ⇒ String
Returns Object type.
27 |
# File 'lib/recurly/resources/add_on_mini.rb', line 27 define_attribute :object, String |