Class: Recurly::Resources::CouponRedemptionRemainingDuration

Inherits:
Recurly::Resource show all
Defined in:
lib/recurly/resources/coupon_redemption_remaining_duration.rb

Instance Attribute Summary collapse

Attributes inherited from Recurly::Resource

#attributes

Method Summary

Methods inherited from Recurly::Resource

#==, #get_response, #inspect, #requires_client?, #to_json, #to_s

Methods included from Schema::SchemaFactory

#schema

Methods included from Schema::ResourceCaster

#cast

Methods included from Schema::SchemaValidator

#get_did_you_mean, #validate!, #validate_attribute!

Instance Attribute Details

#expires_atDateTime

Returns Present when ‘type` is `temporal`. The datetime after which this redemption will no longer apply.

Returns:

  • (DateTime)

    Present when ‘type` is `temporal`. The datetime after which this redemption will no longer apply.



11
# File 'lib/recurly/resources/coupon_redemption_remaining_duration.rb', line 11

define_attribute :expires_at, DateTime

#typeString

Returns The coupon’s duration type. ‘temporal` includes an `expires_at` timestamp. `forever` and `single_use` have no additional fields.

Returns:

  • (String)

    The coupon’s duration type. ‘temporal` includes an `expires_at` timestamp. `forever` and `single_use` have no additional fields.



15
# File 'lib/recurly/resources/coupon_redemption_remaining_duration.rb', line 15

define_attribute :type, String