Class: Recurly::Resources::LineItemDiscount
- Inherits:
-
Recurly::Resource
- Object
- Recurly::Resource
- Recurly::Resources::LineItemDiscount
- Defined in:
- lib/recurly/resources/line_item_discount.rb
Instance Attribute Summary collapse
-
#coupon_id ⇒ String
The ID of the coupon that generated this discount.
-
#coupon_redemption_id ⇒ String
The ID of the coupon redemption that generated this discount.
-
#currency ⇒ String
3-letter ISO 4217 currency code.
-
#discount_amount ⇒ Float
The amount discounted on this line item by this coupon redemption.
-
#object ⇒ String
Will always be ‘line_item_discount`.
-
#order_applied ⇒ Integer
The order in which this discount was applied when multiple coupons were redeemed.
Attributes inherited from Recurly::Resource
Method Summary
Methods inherited from Recurly::Resource
#==, #get_response, #inspect, #requires_client?, #to_json, #to_s
Methods included from Schema::SchemaFactory
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#coupon_id ⇒ String
Returns The ID of the coupon that generated this discount.
11 |
# File 'lib/recurly/resources/line_item_discount.rb', line 11 define_attribute :coupon_id, String |
#coupon_redemption_id ⇒ String
Returns The ID of the coupon redemption that generated this discount.
15 |
# File 'lib/recurly/resources/line_item_discount.rb', line 15 define_attribute :coupon_redemption_id, String |
#currency ⇒ String
Returns 3-letter ISO 4217 currency code.
19 |
# File 'lib/recurly/resources/line_item_discount.rb', line 19 define_attribute :currency, String |
#discount_amount ⇒ Float
Returns The amount discounted on this line item by this coupon redemption.
23 |
# File 'lib/recurly/resources/line_item_discount.rb', line 23 define_attribute :discount_amount, Float |
#object ⇒ String
Returns Will always be ‘line_item_discount`.
27 |
# File 'lib/recurly/resources/line_item_discount.rb', line 27 define_attribute :object, String |
#order_applied ⇒ Integer
Returns The order in which this discount was applied when multiple coupons were redeemed.
31 |
# File 'lib/recurly/resources/line_item_discount.rb', line 31 define_attribute :order_applied, Integer |