Class: Recurly::Resources::UniqueCouponCodeGenerationResponse
- Inherits:
-
Recurly::Resource
- Object
- Recurly::Resource
- Recurly::Resources::UniqueCouponCodeGenerationResponse
- Defined in:
- lib/recurly/resources/unique_coupon_code_generation_response.rb
Instance Attribute Summary collapse
-
#object ⇒ String
Object type.
-
#unique_coupon_codes ⇒ Array[UniqueCouponCode]
An array containing the newly generated unique coupon codes.
Attributes inherited from Recurly::Resource
Method Summary
Methods inherited from Recurly::Resource
#==, #get_response, #inspect, #requires_client?, #to_json, #to_s
Methods included from Schema::SchemaFactory
Methods included from Schema::ResourceCaster
Methods included from Schema::SchemaValidator
#get_did_you_mean, #validate!, #validate_attribute!
Instance Attribute Details
#object ⇒ String
Returns Object type.
11 |
# File 'lib/recurly/resources/unique_coupon_code_generation_response.rb', line 11 define_attribute :object, String |
#unique_coupon_codes ⇒ Array[UniqueCouponCode]
Returns An array containing the newly generated unique coupon codes.
15 |
# File 'lib/recurly/resources/unique_coupon_code_generation_response.rb', line 15 define_attribute :unique_coupon_codes, Array, { :item_type => :UniqueCouponCode } |